<?php
session_start();
require_once '../config.php';

// 检查用户是否登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 初始化变量
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$product_id = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
$warehouse_id = isset($_GET['warehouse_id']) ? intval($_GET['warehouse_id']) : 0;

// 获取所有产品
$stmt = $pdo->query("SELECT id, name FROM products ORDER BY name");
$products = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取所有仓库
$stmt = $pdo->query("SELECT id, name FROM storage_locations ORDER BY name");
$warehouses = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 构建查询条件
$conditions = ["i.last_updated BETWEEN :start_date AND :end_date"];
$params = [
    ':start_date' => $start_date,
    ':end_date' => $end_date
];

if ($product_id > 0) {
    $conditions[] = "i.product_id = :product_id";
    $params[':product_id'] = $product_id;
}

if ($warehouse_id > 0) {
    $conditions[] = "i.storage_location_id = :warehouse_id";
    $params[':warehouse_id'] = $warehouse_id;
}

$where_clause = !empty($conditions) ? "WHERE " . implode(" AND ", $conditions) : "";

// 获取库存概览数据
$sql = "SELECT 
            COUNT(DISTINCT i.product_id) AS total_products,
            SUM(CASE WHEN i.quantity_on_hand > 0 THEN i.quantity_on_hand ELSE 0 END) AS total_stock,
            AVG(i.quantity_on_hand) AS avg_stock_level,
            SUM(i.quantity_on_hand * p.standard_price) AS inventory_value
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        $where_clause";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$overview = $stmt->fetch(PDO::FETCH_ASSOC);

// 获取库存周转率数据
$sql = "SELECT 
            p.name,
            i.quantity_on_hand AS current_stock,
            CASE 
                WHEN p.type = 'finished' THEN 200
                WHEN p.type = 'semi-finished' THEN 300
                ELSE 500
            END AS estimated_monthly_sales,
            (CASE 
                WHEN p.type = 'finished' THEN 200
                WHEN p.type = 'semi-finished' THEN 300
                ELSE 500
            END * 12 / NULLIF(i.quantity_on_hand, 0)) AS turnover_rate
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        $where_clause
        GROUP BY 
            p.id, p.name, i.quantity_on_hand, p.type
        ORDER BY 
            turnover_rate DESC
        LIMIT 10";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$turnover_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取库存月度趋势数据
$sql = "SELECT 
            DATE_FORMAT(i.last_updated, '%Y-%m') AS month,
            SUM(i.quantity_on_hand) AS stock_level,
            COUNT(DISTINCT i.product_id) AS product_count
        FROM 
            inventory i
        $where_clause
        GROUP BY 
            DATE_FORMAT(i.last_updated, '%Y-%m')
        ORDER BY 
            month";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$trend_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 为图表准备数据
$trend_labels = [];
$trend_values = [];
$product_counts = [];

foreach ($trend_data as $data) {
    $trend_labels[] = $data['month'];
    $trend_values[] = $data['stock_level'];
    $product_counts[] = $data['product_count'];
}

// 获取库存分布数据
$sql = "SELECT 
            w.name AS warehouse_name,
            SUM(i.quantity_on_hand) AS total_quantity,
            COUNT(DISTINCT i.product_id) AS product_count
        FROM 
            inventory i
        JOIN 
            storage_locations w ON i.storage_location_id = w.id
        $where_clause
        GROUP BY 
            w.id, w.name
        ORDER BY 
            total_quantity DESC";

$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$distribution_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 为分布图表准备数据
$warehouse_labels = [];
$warehouse_values = [];

foreach ($distribution_data as $data) {
    $warehouse_labels[] = $data['warehouse_name'];
    $warehouse_values[] = $data['total_quantity'];
}

// 获取库存风险数据
$sql = "SELECT 
            p.name,
            i.quantity_on_hand AS quantity,
            i.low_stock_threshold AS reorder_level,
            COALESCE(i.low_stock_threshold * 2, 100) AS target_stock_level,
            CASE 
                WHEN i.quantity_on_hand <= i.low_stock_threshold THEN '低库存风险'
                WHEN i.quantity_on_hand >= COALESCE(i.low_stock_threshold * 2, 100) * 1.5 THEN '过量库存风险'
                ELSE '正常'
            END AS stock_status
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        WHERE 
            (i.quantity_on_hand <= i.low_stock_threshold OR i.quantity_on_hand >= COALESCE(i.low_stock_threshold * 2, 100) * 1.5)
            AND i.last_updated <= :current_date
        ORDER BY 
            CASE 
                WHEN i.quantity_on_hand <= i.low_stock_threshold THEN 1
                WHEN i.quantity_on_hand >= COALESCE(i.low_stock_threshold * 2, 100) * 1.5 THEN 2
                ELSE 3
            END,
            i.quantity_on_hand";

// 使用新的参数数组，只包含current_date
$risk_params = [':current_date' => $end_date];
$stmt = $pdo->prepare($sql);
$stmt->execute($risk_params);
$risk_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取库存准确性数据（基于盘点记录）
$sql = "SELECT 
            p.name,
            ici.system_quantity AS expected_quantity,
            ici.actual_quantity,
            ici.difference AS discrepancy,
            (ici.difference / ici.system_quantity * 100) AS discrepancy_percentage
        FROM 
            inventory_check_items ici
        JOIN 
            products p ON ici.product_id = p.id
        JOIN
            inventory_checks ic ON ici.inventory_check_id = ic.id
        WHERE 
            ic.check_date BETWEEN :start_date AND :end_date
        ORDER BY 
            ABS(ici.difference / ici.system_quantity * 100) DESC
        LIMIT 10";

// 使用新的参数数组，不复用$params
$accuracy_params = [
    ':start_date' => $start_date,
    ':end_date' => $end_date
];

$stmt = $pdo->prepare($sql);
$stmt->execute($accuracy_params);
$accuracy_data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>库存分析 - FruitEase</title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.3.0/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/bootstrap-icons/1.10.0/font/bootstrap-icons.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/chart.js/3.9.1/chart.min.js"></script>
    <script src="https://cdn.bootcdn.net/ajax/libs/echarts/5.4.3/echarts.min.js"></script>
    <style>
        body {
            font-family: "Microsoft YaHei", sans-serif;
            background-color: #f8f9fa;
        }

        .card {
            margin-bottom: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }

        .stat-card {
            text-align: center;
            padding: 15px;
            border-radius: 10px;
            transition: transform 0.3s;
        }

        .stat-card:hover {
            transform: translateY(-5px);
        }

        .stat-icon {
            font-size: 2rem;
            margin-bottom: 10px;
        }

        .stat-value {
            font-size: 1.8rem;
            font-weight: bold;
            margin-bottom: 5px;
        }

        .stat-label {
            font-size: 1rem;
            color: #6c757d;
        }

        .chart-container {
            height: 350px;
            width: 100%;
        }

        .tab-pane {
            padding: 20px;
        }

        .risk-low {
            color: #dc3545;
            background-color: rgba(220, 53, 69, 0.1);
            padding: 0.2rem 0.5rem;
            border-radius: 4px;
        }

        .risk-high {
            color: #ffc107;
            background-color: rgba(255, 193, 7, 0.1);
            padding: 0.2rem 0.5rem;
            border-radius: 4px;
        }

        .risk-normal {
            color: #28a745;
            background-color: rgba(40, 167, 69, 0.1);
            padding: 0.2rem 0.5rem;
            border-radius: 4px;
        }

        table.table {
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
        }
    </style>
</head>

<body>
    <div class="container-fluid py-4">
        <h1 class="mb-4">库存分析</h1>

        <!-- 过滤器 -->
        <div class="card mb-4">
            <div class="card-body">
                <form method="get" class="row g-3">
                    <div class="col-md-3">
                        <label for="start_date" class="form-label">开始日期</label>
                        <input type="date" class="form-control" id="start_date" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>">
                    </div>
                    <div class="col-md-3">
                        <label for="end_date" class="form-label">结束日期</label>
                        <input type="date" class="form-control" id="end_date" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>">
                    </div>
                    <div class="col-md-3">
                        <label for="product_id" class="form-label">产品</label>
                        <select class="form-select" id="product_id" name="product_id">
                            <option value="0">所有产品</option>
                            <?php foreach ($products as $product): ?>
                                <option value="<?php echo $product['id']; ?>" <?php echo $product_id == $product['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($product['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-3">
                        <label for="warehouse_id" class="form-label">仓库</label>
                        <select class="form-select" id="warehouse_id" name="warehouse_id">
                            <option value="0">所有仓库</option>
                            <?php foreach ($warehouses as $warehouse): ?>
                                <option value="<?php echo $warehouse['id']; ?>" <?php echo $warehouse_id == $warehouse['id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($warehouse['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-12 text-end">
                        <button type="submit" class="btn btn-primary">应用筛选</button>
                        <a href="inventory_analysis.php" class="btn btn-secondary">重置筛选</a>
                    </div>
                </form>
            </div>
        </div>

        <!-- 统计卡片 -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="card stat-card bg-primary text-white">
                    <div class="stat-icon"><i class="bi bi-box-seam"></i></div>
                    <div class="stat-value"><?php echo number_format($overview['total_products']); ?></div>
                    <div class="stat-label">库存产品种类</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stat-card bg-success text-white">
                    <div class="stat-icon"><i class="bi bi-layers"></i></div>
                    <div class="stat-value"><?php echo number_format($overview['total_stock']); ?></div>
                    <div class="stat-label">总库存数量</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stat-card bg-info text-white">
                    <div class="stat-icon"><i class="bi bi-graph-up"></i></div>
                    <div class="stat-value"><?php echo number_format($overview['avg_stock_level'], 2); ?></div>
                    <div class="stat-label">平均库存水平</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stat-card bg-warning text-white">
                    <div class="stat-icon"><i class="bi bi-currency-yen"></i></div>
                    <div class="stat-value"><?php echo number_format($overview['inventory_value'], 2); ?></div>
                    <div class="stat-label">库存价值（¥）</div>
                </div>
            </div>
        </div>

        <!-- 选项卡导航 -->
        <ul class="nav nav-tabs" id="inventoryTabs" role="tablist">
            <li class="nav-item" role="presentation">
                <button class="nav-link active" id="overview-tab" data-bs-toggle="tab" data-bs-target="#overview" type="button" role="tab" aria-controls="overview" aria-selected="true">总览</button>
            </li>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="turnover-tab" data-bs-toggle="tab" data-bs-target="#turnover" type="button" role="tab" aria-controls="turnover" aria-selected="false">库存周转</button>
            </li>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="distribution-tab" data-bs-toggle="tab" data-bs-target="#distribution" type="button" role="tab" aria-controls="distribution" aria-selected="false">库存分布</button>
            </li>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="risk-tab" data-bs-toggle="tab" data-bs-target="#risk" type="button" role="tab" aria-controls="risk" aria-selected="false">库存风险</button>
            </li>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="accuracy-tab" data-bs-toggle="tab" data-bs-target="#accuracy" type="button" role="tab" aria-controls="accuracy" aria-selected="false">库存准确性</button>
            </li>
        </ul>

        <!-- 选项卡内容 -->
        <div class="tab-content" id="inventoryTabsContent">
            <!-- 总览选项卡 -->
            <div class="tab-pane fade show active" id="overview" role="tabpanel" aria-labelledby="overview-tab">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存月度趋势</h5>
                        <div class="chart-container" id="trendChart"></div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">关键库存指标说明</h5>
                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>指标</th>
                                        <th>说明</th>
                                        <th>当前值</th>
                                        <th>建议值</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <tr>
                                        <td>库存种类</td>
                                        <td>仓库中存储的不同产品种类数量</td>
                                        <td><?php echo number_format($overview['total_products']); ?></td>
                                        <td>根据业务规模调整</td>
                                    </tr>
                                    <tr>
                                        <td>总库存数量</td>
                                        <td>所有产品的库存总和</td>
                                        <td><?php echo number_format($overview['total_stock']); ?></td>
                                        <td>保持适度，避免过量库存</td>
                                    </tr>
                                    <tr>
                                        <td>平均库存水平</td>
                                        <td>每种产品的平均库存量</td>
                                        <td><?php echo number_format($overview['avg_stock_level'], 2); ?></td>
                                        <td>10-30天的销售量</td>
                                    </tr>
                                    <tr>
                                        <td>库存价值</td>
                                        <td>库存的总货币价值</td>
                                        <td>¥<?php echo number_format($overview['inventory_value'], 2); ?></td>
                                        <td>控制在资金规模的20-30%</td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 库存周转选项卡 -->
            <div class="tab-pane fade" id="turnover" role="tabpanel" aria-labelledby="turnover-tab">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存周转率分析</h5>
                        <div class="chart-container" id="turnoverChart"></div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存周转率详情</h5>
                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>产品名称</th>
                                        <th>当前库存</th>
                                        <th>月均销售量</th>
                                        <th>周转率</th>
                                        <th>评价</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($turnover_data as $data): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($data['name']); ?></td>
                                            <td><?php echo number_format($data['current_stock']); ?></td>
                                            <td><?php echo number_format($data['estimated_monthly_sales']); ?></td>
                                            <td><?php echo number_format($data['turnover_rate'], 2); ?></td>
                                            <td>
                                                <?php
                                                $rate = $data['turnover_rate'];
                                                if ($rate < 2) {
                                                    echo '<span class="badge bg-danger">低周转</span>';
                                                } elseif ($rate < 4) {
                                                    echo '<span class="badge bg-warning">一般</span>';
                                                } else {
                                                    echo '<span class="badge bg-success">高周转</span>';
                                                }
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 库存分布选项卡 -->
            <div class="tab-pane fade" id="distribution" role="tabpanel" aria-labelledby="distribution-tab">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存仓库分布</h5>
                        <div class="chart-container" id="distributionChart"></div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">仓库库存详情</h5>
                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>仓库名称</th>
                                        <th>产品种类</th>
                                        <th>总库存量</th>
                                        <th>占总库存比例</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php
                                    $total_inventory = array_sum(array_column($distribution_data, 'total_quantity'));
                                    foreach ($distribution_data as $data):
                                    ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($data['warehouse_name']); ?></td>
                                            <td><?php echo number_format($data['product_count']); ?></td>
                                            <td><?php echo number_format($data['total_quantity']); ?></td>
                                            <td>
                                                <?php
                                                $percentage = ($data['total_quantity'] / $total_inventory) * 100;
                                                echo number_format($percentage, 2) . '%';
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 库存风险选项卡 -->
            <div class="tab-pane fade" id="risk" role="tabpanel" aria-labelledby="risk-tab">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存风险分析</h5>
                        <div class="alert alert-info">
                            <i class="bi bi-info-circle"></i>
                            此报告显示需要关注的库存风险项目，包括库存不足和库存过量的产品。
                        </div>

                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>产品名称</th>
                                        <th>当前库存</th>
                                        <th>重订点</th>
                                        <th>目标库存</th>
                                        <th>状态</th>
                                        <th>建议</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($risk_data as $data): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($data['name']); ?></td>
                                            <td><?php echo number_format($data['quantity']); ?></td>
                                            <td><?php echo number_format($data['reorder_level']); ?></td>
                                            <td><?php echo number_format($data['target_stock_level']); ?></td>
                                            <td>
                                                <?php
                                                if ($data['stock_status'] == '低库存风险') {
                                                    echo '<span class="risk-low">低库存风险</span>';
                                                } elseif ($data['stock_status'] == '过量库存风险') {
                                                    echo '<span class="risk-high">过量库存风险</span>';
                                                } else {
                                                    echo '<span class="risk-normal">正常</span>';
                                                }
                                                ?>
                                            </td>
                                            <td>
                                                <?php
                                                if ($data['stock_status'] == '低库存风险') {
                                                    echo '立即补货至目标库存水平';
                                                } elseif ($data['stock_status'] == '过量库存风险') {
                                                    echo '考虑促销或调整采购计划';
                                                } else {
                                                    echo '保持当前库存管理策略';
                                                }
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 库存准确性选项卡 -->
            <div class="tab-pane fade" id="accuracy" role="tabpanel" aria-labelledby="accuracy-tab">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">库存准确性分析</h5>
                        <div class="alert alert-warning">
                            <i class="bi bi-exclamation-triangle"></i>
                            此报告基于盘点记录，显示实际库存与系统记录之间的差异。
                        </div>

                        <div class="table-responsive">
                            <table class="table table-striped">
                                <thead>
                                    <tr>
                                        <th>产品名称</th>
                                        <th>系统记录数量</th>
                                        <th>实际盘点数量</th>
                                        <th>差异</th>
                                        <th>差异百分比</th>
                                        <th>状态</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($accuracy_data as $data): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($data['name']); ?></td>
                                            <td><?php echo number_format($data['expected_quantity']); ?></td>
                                            <td><?php echo number_format($data['actual_quantity']); ?></td>
                                            <td><?php echo number_format($data['discrepancy']); ?></td>
                                            <td><?php echo number_format($data['discrepancy_percentage'], 2); ?>%</td>
                                            <td>
                                                <?php
                                                $percentage = abs($data['discrepancy_percentage']);
                                                if ($percentage > 10) {
                                                    echo '<span class="badge bg-danger">严重不准确</span>';
                                                } elseif ($percentage > 5) {
                                                    echo '<span class="badge bg-warning">需要改进</span>';
                                                } else {
                                                    echo '<span class="badge bg-success">准确</span>';
                                                }
                                                ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">改善库存准确性的建议</h5>
                        <ul class="list-group">
                            <li class="list-group-item">
                                <i class="bi bi-check-circle text-success"></i>
                                定期进行盘点，至少每季度一次全面盘点
                            </li>
                            <li class="list-group-item">
                                <i class="bi bi-check-circle text-success"></i>
                                为高价值产品实施周循环盘点
                            </li>
                            <li class="list-group-item">
                                <i class="bi bi-check-circle text-success"></i>
                                使用条形码或RFID技术提高库存跟踪准确性
                            </li>
                            <li class="list-group-item">
                                <i class="bi bi-check-circle text-success"></i>
                                培训仓库人员正确执行库存收发流程
                            </li>
                            <li class="list-group-item">
                                <i class="bi bi-check-circle text-success"></i>
                                实施仓库管理系统(WMS)以减少人为错误
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/bootstrap/5.3.0/js/bootstrap.bundle.min.js"></script>
    <script>
        // 初始化月度趋势图表
        var trendChart = echarts.init(document.getElementById('trendChart'));
        var trendOption = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {
                data: ['库存水平', '产品种类']
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                data: <?php echo json_encode($trend_labels); ?>
            }],
            yAxis: [{
                    type: 'value',
                    name: '库存水平',
                    position: 'left'
                },
                {
                    type: 'value',
                    name: '产品种类',
                    position: 'right'
                }
            ],
            series: [{
                    name: '库存水平',
                    type: 'bar',
                    data: <?php echo json_encode($trend_values); ?>
                },
                {
                    name: '产品种类',
                    type: 'line',
                    yAxisIndex: 1,
                    data: <?php echo json_encode($product_counts); ?>
                }
            ]
        };
        trendChart.setOption(trendOption);

        // 初始化周转率图表
        var turnoverChart = echarts.init(document.getElementById('turnoverChart'));
        var turnoverOption = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: <?php echo json_encode(array_column($turnover_data, 'name')); ?>,
                axisLabel: {
                    interval: 0,
                    rotate: 30
                }
            },
            yAxis: {
                type: 'value',
                name: '周转率'
            },
            series: [{
                name: '周转率',
                type: 'bar',
                data: <?php echo json_encode(array_column($turnover_data, 'turnover_rate')); ?>,
                itemStyle: {
                    color: function(params) {
                        var rate = params.value;
                        if (rate < 2) return '#dc3545'; // 低周转
                        if (rate < 4) return '#ffc107'; // 一般
                        return '#28a745'; // 高周转
                    }
                }
            }]
        };
        turnoverChart.setOption(turnoverOption);

        // 初始化库存分布图表
        var distributionChart = echarts.init(document.getElementById('distributionChart'));
        var distributionOption = {
            tooltip: {
                trigger: 'item',
                formatter: '{a} <br/>{b}: {c} ({d}%)'
            },
            legend: {
                orient: 'vertical',
                left: 10,
                data: <?php echo json_encode($warehouse_labels); ?>
            },
            series: [{
                name: '库存分布',
                type: 'pie',
                radius: ['50%', '70%'],
                avoidLabelOverlap: false,
                itemStyle: {
                    borderRadius: 10,
                    borderColor: '#fff',
                    borderWidth: 2
                },
                label: {
                    show: false,
                    position: 'center'
                },
                emphasis: {
                    label: {
                        show: true,
                        fontSize: '16',
                        fontWeight: 'bold'
                    }
                },
                labelLine: {
                    show: false
                },
                data: [
                    <?php
                    for ($i = 0; $i < count($warehouse_labels); $i++) {
                        echo "{value: " . $warehouse_values[$i] . ", name: '" . $warehouse_labels[$i] . "'}";
                        if ($i < count($warehouse_labels) - 1) echo ",";
                    }
                    ?>
                ]
            }]
        };
        distributionChart.setOption(distributionOption);

        // 监听选项卡切换事件，重新渲染图表
        document.querySelectorAll('.nav-link').forEach(function(tabEl) {
            tabEl.addEventListener('shown.bs.tab', function(event) {
                const targetId = event.target.getAttribute('data-bs-target');

                if (targetId === '#overview') {
                    trendChart.resize();
                } else if (targetId === '#turnover') {
                    turnoverChart.resize();
                } else if (targetId === '#distribution') {
                    distributionChart.resize();
                }
            });
        });

        // 窗口大小调整时重新调整图表大小
        window.addEventListener('resize', function() {
            trendChart.resize();
            turnoverChart.resize();
            distributionChart.resize();
        });
    </script>
</body>

</html>