<?php
session_start();
// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 包含数据库连接
require_once '../config.php';

// 检查CSRF令牌
if (!isset($_POST['csrf_token']) || !isset($_SESSION['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
    $_SESSION['error'] = "安全验证失败，请重试。";
    header("Location: receivable_payable_management.php");
    exit;
}

// 初始化响应
$response = [
    'success' => false,
    'message' => '未知错误',
    'redirect' => 'receivable_payable_management.php'
];

try {
    // 处理应收账款付款
    if (isset($_POST['action']) && $_POST['action'] === 'receive_payment') {
        // 验证必要参数
        if (!isset($_POST['receivable_id'], $_POST['payment_amount'], $_POST['payment_date'], $_POST['payment_method'])) {
            throw new Exception("缺少必要参数");
        }

        $receivable_id = (int)$_POST['receivable_id'];
        $payment_amount = (float)$_POST['payment_amount'];
        $payment_date = $_POST['payment_date'];
        $payment_method = $_POST['payment_method'];
        $reference_number = isset($_POST['reference_number']) ? $_POST['reference_number'] : '';
        $notes = isset($_POST['notes']) ? $_POST['notes'] : '';

        // 验证金额是否合法
        if ($payment_amount <= 0) {
            throw new Exception("付款金额必须大于0");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 获取当前应收账款信息
        $stmt = $pdo->prepare("
            SELECT balance, amount, paid_amount
            FROM receivables
            WHERE id = ?
        ");
        $stmt->execute([$receivable_id]);
        $receivable = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$receivable) {
            throw new Exception("应收账款记录不存在");
        }

        // 验证付款金额不超过剩余金额
        if ($payment_amount > $receivable['balance']) {
            throw new Exception("付款金额不能超过剩余应收金额");
        }

        // 记录付款
        $stmt = $pdo->prepare("
            INSERT INTO payments_received 
            (receivable_id, amount, payment_date, payment_method, reference_number, notes) 
            VALUES (?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $receivable_id,
            $payment_amount,
            $payment_date,
            $payment_method,
            $reference_number,
            $notes
        ]);

        // 更新应收账款记录
        $new_paid_amount = $receivable['paid_amount'] + $payment_amount;
        $new_balance = $receivable['amount'] - $new_paid_amount;

        // 确定新的状态
        $new_status = 'pending';
        if ($new_balance <= 0) {
            $new_status = 'paid';
        } else if ($new_paid_amount > 0) {
            $new_status = 'partial';
        } else {
            // 检查是否逾期
            $due_date_query = $pdo->prepare("SELECT due_date FROM receivables WHERE id = ?");
            $due_date_query->execute([$receivable_id]);
            $due_date = $due_date_query->fetchColumn();

            if (strtotime($due_date) < strtotime('today')) {
                $new_status = 'overdue';
            }
        }

        $stmt = $pdo->prepare("
            UPDATE receivables
            SET paid_amount = paid_amount + ?, status = ?
            WHERE id = ?
        ");
        $stmt->execute([$payment_amount, $new_status, $receivable_id]);

        // 提交事务
        $pdo->commit();

        // 设置成功消息
        $_SESSION['success'] = "收款记录已成功保存";
        header("Location: receivable_payable_management.php?type=receivables");
        exit;
    }
    // 处理应付账款付款
    else if (isset($_POST['action']) && $_POST['action'] === 'make_payment') {
        // 验证必要参数
        if (!isset($_POST['payable_id'], $_POST['payment_amount'], $_POST['payment_date'], $_POST['payment_method'])) {
            throw new Exception("缺少必要参数");
        }

        $payable_id = (int)$_POST['payable_id'];
        $payment_amount = (float)$_POST['payment_amount'];
        $payment_date = $_POST['payment_date'];
        $payment_method = $_POST['payment_method'];
        $reference_number = isset($_POST['reference_number']) ? $_POST['reference_number'] : '';
        $notes = isset($_POST['notes']) ? $_POST['notes'] : '';

        // 验证金额是否合法
        if ($payment_amount <= 0) {
            throw new Exception("付款金额必须大于0");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 获取当前应付账款信息
        $stmt = $pdo->prepare("
            SELECT balance, amount, paid_amount
            FROM payables
            WHERE id = ?
        ");
        $stmt->execute([$payable_id]);
        $payable = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$payable) {
            throw new Exception("应付账款记录不存在");
        }

        // 验证付款金额不超过剩余金额
        if ($payment_amount > $payable['balance']) {
            throw new Exception("付款金额不能超过剩余应付金额");
        }

        // 记录付款
        $stmt = $pdo->prepare("
            INSERT INTO payments_made 
            (payable_id, amount, payment_date, payment_method, reference_number, notes) 
            VALUES (?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $payable_id,
            $payment_amount,
            $payment_date,
            $payment_method,
            $reference_number,
            $notes
        ]);

        // 更新应付账款记录
        $new_paid_amount = $payable['paid_amount'] + $payment_amount;
        $new_balance = $payable['amount'] - $new_paid_amount;

        // 确定新的状态
        $new_status = 'pending';
        if ($new_balance <= 0) {
            $new_status = 'paid';
        } else if ($new_paid_amount > 0) {
            $new_status = 'partial';
        } else {
            // 检查是否逾期
            $due_date_query = $pdo->prepare("SELECT due_date FROM payables WHERE id = ?");
            $due_date_query->execute([$payable_id]);
            $due_date = $due_date_query->fetchColumn();

            if (strtotime($due_date) < strtotime('today')) {
                $new_status = 'overdue';
            }
        }

        $stmt = $pdo->prepare("
            UPDATE payables
            SET paid_amount = paid_amount + ?, status = ?
            WHERE id = ?
        ");
        $stmt->execute([$payment_amount, $new_status, $payable_id]);

        // 提交事务
        $pdo->commit();

        // 设置成功消息
        $_SESSION['success'] = "付款记录已成功保存";
        header("Location: receivable_payable_management.php?type=payables");
        exit;
    } else {
        throw new Exception("未知的操作类型");
    }
} catch (Exception $e) {
    // 回滚事务
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }

    // 设置错误消息
    $_SESSION['error'] = "操作失败：" . $e->getMessage();
    header("Location: receivable_payable_management.php");
    exit;
}
