<?php
// finance/production_cost_analysis.php - 生产成本核算页面
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查并创建必要的数据表
try {
    // 使用config.php中的$pdo变量

    // 检查FruitEase.sql中production_batches表是否已定义
    // 该表已在SQL/FruitEase.sql中定义，结构为:
    /*
    CREATE TABLE `production_batches` (
      `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '生产批次ID',
      `batch_number` VARCHAR(50) NOT NULL COMMENT '生产批次号',
      `production_plan_id` INT UNSIGNED DEFAULT NULL COMMENT '关联生产计划ID (可选)',
      `product_id` INT UNSIGNED NOT NULL COMMENT '生产产品ID (成品或半成品)',
      `quantity_planned` DECIMAL(10, 2) DEFAULT NULL COMMENT '计划生产量',
      `quantity_produced` DECIMAL(10, 2) DEFAULT NULL COMMENT '实际产量',
      `start_time` DATETIME DEFAULT NULL COMMENT '实际开始时间',
      `end_time` DATETIME DEFAULT NULL COMMENT '实际结束时间',
      `status` ENUM('planned', 'in_progress', 'completed', 'quality_check', 'stocked', 'cancelled') NOT NULL DEFAULT 'planned' COMMENT '批次状态',
      `estimated_cost` DECIMAL(12, 2) DEFAULT NULL COMMENT '预计成本',
      `actual_cost` DECIMAL(12, 2) DEFAULT NULL COMMENT '实际成本',
      `notes` TEXT DEFAULT NULL COMMENT '备注',
      `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间'
    */

    // 先检查数据库中是否存在production_batches表
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'production_batches'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 表不存在，创建表
        $sql = "CREATE TABLE production_batches (
            id INT AUTO_INCREMENT PRIMARY KEY,
            batch_number VARCHAR(20) NOT NULL,
            product_id INT NOT NULL,
            production_plan_id INT DEFAULT NULL,
            quantity_planned DECIMAL(10,2) DEFAULT NULL,
            quantity_produced DECIMAL(10,2) DEFAULT NULL,
            start_time DATETIME DEFAULT NULL,
            end_time DATETIME DEFAULT NULL,
            material_cost DECIMAL(10,2) DEFAULT 0,
            labor_cost DECIMAL(10,2) DEFAULT 0,
            overhead_cost DECIMAL(10,2) DEFAULT 0,
            total_cost DECIMAL(10,2) DEFAULT 0,
            unit_cost DECIMAL(10,2) DEFAULT 0,
            status ENUM('planned', 'in_progress', 'completed', 'quality_check', 'stocked', 'cancelled') NOT NULL DEFAULT 'planned',
            notes TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    } else {
        // 检查表是否有material_cost, labor_cost, overhead_cost, total_cost, unit_cost字段
        // 如果没有，需要添加这些字段
        $stmt = $pdo->prepare("SHOW COLUMNS FROM production_batches LIKE 'material_cost'");
        $stmt->execute();
        if ($stmt->rowCount() == 0) {
            $pdo->exec("ALTER TABLE production_batches ADD COLUMN material_cost DECIMAL(10,2) DEFAULT 0 AFTER end_time");
        }

        $stmt = $pdo->prepare("SHOW COLUMNS FROM production_batches LIKE 'labor_cost'");
        $stmt->execute();
        if ($stmt->rowCount() == 0) {
            $pdo->exec("ALTER TABLE production_batches ADD COLUMN labor_cost DECIMAL(10,2) DEFAULT 0 AFTER material_cost");
        }

        $stmt = $pdo->prepare("SHOW COLUMNS FROM production_batches LIKE 'overhead_cost'");
        $stmt->execute();
        if ($stmt->rowCount() == 0) {
            $pdo->exec("ALTER TABLE production_batches ADD COLUMN overhead_cost DECIMAL(10,2) DEFAULT 0 AFTER labor_cost");
        }

        $stmt = $pdo->prepare("SHOW COLUMNS FROM production_batches LIKE 'total_cost'");
        $stmt->execute();
        if ($stmt->rowCount() == 0) {
            $pdo->exec("ALTER TABLE production_batches ADD COLUMN total_cost DECIMAL(10,2) DEFAULT 0 AFTER overhead_cost");
        }

        $stmt = $pdo->prepare("SHOW COLUMNS FROM production_batches LIKE 'unit_cost'");
        $stmt->execute();
        if ($stmt->rowCount() == 0) {
            $pdo->exec("ALTER TABLE production_batches ADD COLUMN unit_cost DECIMAL(10,2) DEFAULT 0 AFTER total_cost");
        }
    }

    // 检查生产批次材料表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'production_batch_materials'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建生产批次材料表
        $sql = "CREATE TABLE production_batch_materials (
            id INT AUTO_INCREMENT PRIMARY KEY,
            batch_id INT NOT NULL,
            material_id INT NOT NULL,
            quantity DECIMAL(10,2) NOT NULL,
            unit_cost DECIMAL(10,2) NOT NULL,
            total_cost DECIMAL(10,2) NOT NULL,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    }

    // 检查产品成本表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'product_costs'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建产品成本表
        $sql = "CREATE TABLE product_costs (
            id INT AUTO_INCREMENT PRIMARY KEY,
            product_id INT NOT NULL,
            calculation_date DATE NOT NULL,
            material_cost DECIMAL(10,2) NOT NULL,
            labor_cost DECIMAL(10,2) NOT NULL,
            overhead_cost DECIMAL(10,2) NOT NULL,
            packaging_cost DECIMAL(10,2) NOT NULL,
            other_cost DECIMAL(10,2) NOT NULL,
            total_cost DECIMAL(10,2) NOT NULL,
            notes TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    }

    // 获取生产批次数据（过去6个月）- 修正查询，使用start_time替代production_date
    $stmt = $pdo->prepare("
        SELECT 
            pb.*, 
            p.name AS product_name
        FROM 
            production_batches pb
        LEFT JOIN 
            products p ON pb.product_id = p.id
        WHERE 
            pb.start_time >= DATE_SUB(CURDATE(), INTERVAL 6 MONTH)
        ORDER BY 
            pb.start_time DESC
    ");
    $stmt->execute();
    $productionBatches = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取产品成本数据
    $stmt = $pdo->prepare("
        SELECT 
            pc.*,
            p.name AS product_name
        FROM 
            product_costs pc
        LEFT JOIN 
            products p ON pc.product_id = p.id
        ORDER BY 
            pc.calculation_date DESC
    ");
    $stmt->execute();
    $productCosts = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 计算平均成本 - 修正查询，使用start_time替代production_date
    $stmt = $pdo->prepare("
        SELECT 
            AVG(unit_cost) AS avg_unit_cost,
            AVG(material_cost/total_cost) AS avg_material_ratio,
            AVG(labor_cost/total_cost) AS avg_labor_ratio,
            AVG(overhead_cost/total_cost) AS avg_overhead_ratio
        FROM 
            production_batches
        WHERE 
            start_time >= DATE_SUB(CURDATE(), INTERVAL 6 MONTH)
            AND status = 'completed'
    ");
    $stmt->execute();
    $avgCostResult = $stmt->fetch(PDO::FETCH_ASSOC);

    $avgUnitCost = $avgCostResult['avg_unit_cost'] ?: 0;
    $avgMaterialRatio = $avgCostResult['avg_material_ratio'] ? round($avgCostResult['avg_material_ratio'] * 100, 2) : 0;
    $avgLaborRatio = $avgCostResult['avg_labor_ratio'] ? round($avgCostResult['avg_labor_ratio'] * 100, 2) : 0;
    $avgOverheadRatio = $avgCostResult['avg_overhead_ratio'] ? round($avgCostResult['avg_overhead_ratio'] * 100, 2) : 0;

    // 获取按产品统计的成本数据 - 修正查询，使用start_time替代production_date
    $stmt = $pdo->prepare("
        SELECT 
            p.name AS product_name,
            COUNT(pb.id) AS batch_count,
            AVG(pb.unit_cost) AS avg_unit_cost,
            SUM(pb.total_cost) AS total_cost
        FROM 
            production_batches pb
        LEFT JOIN 
            products p ON pb.product_id = p.id
        WHERE 
            pb.status = 'completed'
            AND pb.start_time >= DATE_SUB(CURDATE(), INTERVAL 6 MONTH)
        GROUP BY 
            pb.product_id
        ORDER BY 
            total_cost DESC
        LIMIT 10
    ");
    $stmt->execute();
    $productCostStats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取月度成本趋势 - 修正查询，使用start_time替代production_date
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(start_time, '%Y-%m') AS month,
            SUM(total_cost) AS monthly_cost,
            AVG(unit_cost) AS avg_unit_cost
        FROM 
            production_batches
        WHERE 
            start_time >= DATE_SUB(CURDATE(), INTERVAL 6 MONTH)
            AND status = 'completed'
        GROUP BY 
            DATE_FORMAT(start_time, '%Y-%m')
        ORDER BY 
            month
    ");
    $stmt->execute();
    $monthlyCosts = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 准备月度成本图表数据
    $months = [];
    $monthlyCostData = [];
    $monthlyUnitCostData = [];

    foreach ($monthlyCosts as $cost) {
        $months[] = $cost['month'];
        $monthlyCostData[] = $cost['monthly_cost'];
        $monthlyUnitCostData[] = $cost['avg_unit_cost'];
    }
} catch (PDOException $e) {
    $error = "数据库错误: " . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产成本核算 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/Chart.js/3.9.1/chart.min.js"></script>
    <style>
        .container {
            max-width: 1000px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .dashboard {
            display: grid;
            grid-template-columns: repeat(4, 1fr);
            gap: 20px;
            margin-bottom: 30px;
        }

        .card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            text-align: center;
        }

        .card h3 {
            color: #555;
            font-size: 16px;
            margin-bottom: 10px;
        }

        .card .value {
            color: #2c3e50;
            font-size: 24px;
            font-weight: bold;
        }

        .card .subtext {
            color: #7f8c8d;
            font-size: 14px;
            margin-top: 5px;
        }

        .chart-container {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            padding-bottom: 90px;
            margin-bottom: 30px;
            min-height: 450px;
        }

        .chart-grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
            margin-bottom: 30px;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
            border-bottom: none;
            border-radius: 4px 4px 0 0;
            margin-right: 5px;
        }

        .tab.active {
            background: #fff;
            border-color: #ddd;
            border-bottom: 1px solid #fff;
            margin-bottom: -1px;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .ratio-container {
            display: flex;
            height: 30px;
            width: 100%;
            background: #f0f0f0;
            border-radius: 4px;
            overflow: hidden;
            margin-top: 10px;
        }

        .ratio-bar {
            height: 100%;
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            font-size: 12px;
        }

        .material-bar {
            background-color: rgba(255, 99, 132, 0.7);
        }

        .labor-bar {
            background-color: rgba(54, 162, 235, 0.7);
        }

        .overhead-bar {
            background-color: rgba(255, 206, 86, 0.7);
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>生产成本核算</h1>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php else: ?>
            <!-- 成本概览 -->
            <section class="dashboard">
                <div class="card">
                    <h3>平均单位成本</h3>
                    <div class="value"><?= number_format($avgUnitCost, 2) ?> 元</div>
                    <div class="subtext">过去6个月完成批次</div>
                </div>
                <div class="card">
                    <h3>平均成本构成</h3>
                    <div class="ratio-container">
                        <div class="ratio-bar material-bar" style="width: <?= $avgMaterialRatio ?>%;"><?= $avgMaterialRatio ?>%</div>
                        <div class="ratio-bar labor-bar" style="width: <?= $avgLaborRatio ?>%;"><?= $avgLaborRatio ?>%</div>
                        <div class="ratio-bar overhead-bar" style="width: <?= $avgOverheadRatio ?>%;"><?= $avgOverheadRatio ?>%</div>
                    </div>
                    <div class="subtext">材料、人工、间接费用比例</div>
                </div>
                <div class="card">
                    <h3>批次总数</h3>
                    <div class="value"><?= count($productionBatches) ?></div>
                    <div class="subtext">过去6个月生产批次</div>
                </div>
                <div class="card">
                    <h3>产品成本分析</h3>
                    <div class="value"><?= count($productCosts) ?></div>
                    <div class="subtext">记录的产品成本分析</div>
                </div>
            </section>

            <!-- 成本图表 -->
            <section class="chart-grid">
                <div class="chart-container">
                    <h2>月度成本趋势</h2>
                    <canvas id="monthlyCostChart"></canvas>
                </div>
                <div class="chart-container">
                    <h2>产品单位成本对比</h2>
                    <canvas id="productCostChart"></canvas>
                </div>
            </section>

            <!-- 成本详情标签页 -->
            <section class="tab-container">
                <div class="tabs">
                    <div class="tab active" onclick="openTab(event, 'batchCostTab')">单批次成本分析</div>
                    <div class="tab" onclick="openTab(event, 'productCostTab')">成品成本计算</div>
                </div>

                <!-- 单批次成本分析标签内容 -->
                <div id="batchCostTab" class="tab-content active">
                    <h2>生产批次成本明细</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>批次编号</th>
                                <th>产品名称</th>
                                <th>生产日期</th>
                                <th>数量</th>
                                <th>材料成本 (元)</th>
                                <th>人工成本 (元)</th>
                                <th>间接成本 (元)</th>
                                <th>总成本 (元)</th>
                                <th>单位成本 (元)</th>
                                <th>状态</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($productionBatches) > 0): ?>
                                <?php foreach ($productionBatches as $batch): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($batch['batch_number']) ?></td>
                                        <td><?= htmlspecialchars($batch['product_name'] ?? '未知产品') ?></td>
                                        <td><?= htmlspecialchars($batch['start_time']) ?></td>
                                        <td><?= htmlspecialchars($batch['quantity_produced']) ?></td>
                                        <td><?= number_format($batch['material_cost'], 2) ?></td>
                                        <td><?= number_format($batch['labor_cost'], 2) ?></td>
                                        <td><?= number_format($batch['overhead_cost'], 2) ?></td>
                                        <td><?= number_format($batch['total_cost'], 2) ?></td>
                                        <td><?= number_format($batch['unit_cost'], 2) ?></td>
                                        <td>
                                            <?php
                                            $status = $batch['status'];
                                            $statusMap = [
                                                'planned' => '计划中',
                                                'in_progress' => '生产中',
                                                'completed' => '已完成',
                                                'quality_check' => '质量检查中',
                                                'stocked' => '已入库',
                                                'cancelled' => '已取消'
                                            ];
                                            echo $statusMap[$status] ?? $status;
                                            ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="10" class="text-center">暂无生产批次记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 成品成本计算标签内容 -->
                <div id="productCostTab" class="tab-content">
                    <h2>成品成本计算明细</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>计算日期</th>
                                <th>材料成本 (元)</th>
                                <th>人工成本 (元)</th>
                                <th>间接成本 (元)</th>
                                <th>包装成本 (元)</th>
                                <th>其他成本 (元)</th>
                                <th>总成本 (元)</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($productCosts) > 0): ?>
                                <?php foreach ($productCosts as $cost): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($cost['product_name'] ?? '未知产品') ?></td>
                                        <td><?= htmlspecialchars($cost['calculation_date']) ?></td>
                                        <td><?= number_format($cost['material_cost'], 2) ?></td>
                                        <td><?= number_format($cost['labor_cost'], 2) ?></td>
                                        <td><?= number_format($cost['overhead_cost'], 2) ?></td>
                                        <td><?= number_format($cost['packaging_cost'], 2) ?></td>
                                        <td><?= number_format($cost['other_cost'], 2) ?></td>
                                        <td><?= number_format($cost['total_cost'], 2) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无产品成本记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </section>
        <?php endif; ?>
    </div>

    <script>
        // 标签页切换
        function openTab(evt, tabId) {
            var i, tabContent, tabLinks;

            // 隐藏所有标签页内容
            tabContent = document.getElementsByClassName("tab-content");
            for (i = 0; i < tabContent.length; i++) {
                tabContent[i].className = tabContent[i].className.replace(" active", "");
            }

            // 移除所有标签的active状态
            tabLinks = document.getElementsByClassName("tab");
            for (i = 0; i < tabLinks.length; i++) {
                tabLinks[i].className = tabLinks[i].className.replace(" active", "");
            }

            // 显示当前标签页并添加active状态
            document.getElementById(tabId).className += " active";
            evt.currentTarget.className += " active";
        }

        // 月度成本趋势图表
        document.addEventListener('DOMContentLoaded', function() {
            var ctx = document.getElementById('monthlyCostChart').getContext('2d');

            var monthlyCostChart = new Chart(ctx, {
                type: 'line',
                data: {
                    labels: <?= json_encode($months) ?>,
                    datasets: [{
                            label: '月度总成本',
                            data: <?= json_encode($monthlyCostData) ?>,
                            borderColor: 'rgba(54, 162, 235, 1)',
                            backgroundColor: 'rgba(54, 162, 235, 0.1)',
                            borderWidth: 2,
                            fill: true,
                            yAxisID: 'y'
                        },
                        {
                            label: '月度平均单位成本',
                            data: <?= json_encode($monthlyUnitCostData) ?>,
                            borderColor: 'rgba(255, 99, 132, 1)',
                            backgroundColor: 'rgba(255, 99, 132, 0.1)',
                            borderWidth: 2,
                            fill: false,
                            yAxisID: 'y1'
                        }
                    ]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            type: 'linear',
                            display: true,
                            position: 'left',
                            title: {
                                display: true,
                                text: '总成本 (元)'
                            }
                        },
                        y1: {
                            type: 'linear',
                            display: true,
                            position: 'right',
                            title: {
                                display: true,
                                text: '单位成本 (元)'
                            },
                            grid: {
                                drawOnChartArea: false
                            }
                        }
                    }
                }
            });

            // 产品单位成本对比图表
            var productCtx = document.getElementById('productCostChart').getContext('2d');

            var productNames = [];
            var avgUnitCosts = [];
            var batchCounts = [];

            <?php foreach ($productCostStats as $stat): ?>
                productNames.push("<?= htmlspecialchars($stat['product_name'] ?? '未知产品') ?>");
                avgUnitCosts.push(<?= $stat['avg_unit_cost'] ?>);
                batchCounts.push(<?= $stat['batch_count'] ?>);
            <?php endforeach; ?>

            var productCostChart = new Chart(productCtx, {
                type: 'bar',
                data: {
                    labels: productNames,
                    datasets: [{
                            label: '平均单位成本',
                            data: avgUnitCosts,
                            backgroundColor: 'rgba(255, 99, 132, 0.7)',
                            borderColor: 'rgba(255, 99, 132, 1)',
                            borderWidth: 1,
                            yAxisID: 'y'
                        },
                        {
                            label: '批次数量',
                            data: batchCounts,
                            backgroundColor: 'rgba(54, 162, 235, 0.7)',
                            borderColor: 'rgba(54, 162, 235, 1)',
                            borderWidth: 1,
                            type: 'line',
                            yAxisID: 'y1'
                        }
                    ]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    scales: {
                        y: {
                            type: 'linear',
                            display: true,
                            position: 'left',
                            title: {
                                display: true,
                                text: '单位成本 (元)'
                            },
                            beginAtZero: true
                        },
                        y1: {
                            type: 'linear',
                            display: true,
                            position: 'right',
                            title: {
                                display: true,
                                text: '批次数量'
                            },
                            beginAtZero: true,
                            grid: {
                                drawOnChartArea: false
                            }
                        }
                    }
                }
            });
        });
    </script>
</body>

</html>