<?php
// finance/sales_revenue_statistics.php - 销售收入统计页面
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化参数
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-12 months'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$filter_type = isset($_GET['filter_type']) ? $_GET['filter_type'] : '';
$filter_value = isset($_GET['filter_value']) ? $_GET['filter_value'] : '';

// 错误和消息
$error = '';
$success = '';

// 检查数据库表是否存在
try {
    // 检查sales_orders表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'sales_orders'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        throw new Exception("销售订单表不存在，请确保数据库已正确初始化");
    }

    // 检查sales_order_items表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'sales_order_items'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        throw new Exception("销售订单项表不存在，请确保数据库已正确初始化");
    }

    // 获取销售订单数据
    $baseOrderQuery = "
        SELECT 
            so.id,
            so.order_number,
            so.order_date,
            so.total_amount,
            so.status,
            c.name AS customer_name,
            c.region,
            sc.name AS channel_name
        FROM 
            sales_orders so
        LEFT JOIN 
            customers c ON so.customer_id = c.id
        LEFT JOIN 
            sales_channels sc ON so.sales_channel_id = sc.id
        WHERE 
            so.order_date BETWEEN :start_date AND :end_date
    ";

    // 添加筛选条件
    if ($filter_type == 'customer' && !empty($filter_value)) {
        $baseOrderQuery .= " AND c.id = :filter_value";
    } else if ($filter_type == 'region' && !empty($filter_value)) {
        $baseOrderQuery .= " AND c.region = :filter_value";
    } else if ($filter_type == 'channel' && !empty($filter_value)) {
        $baseOrderQuery .= " AND sc.id = :filter_value";
    }

    $baseOrderQuery .= " ORDER BY so.order_date DESC";

    $stmt = $pdo->prepare($baseOrderQuery);
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);

    if (($filter_type == 'customer' || $filter_type == 'channel') && !empty($filter_value)) {
        $stmt->bindParam(':filter_value', $filter_value, PDO::PARAM_INT);
    } else if ($filter_type == 'region' && !empty($filter_value)) {
        $stmt->bindParam(':filter_value', $filter_value);
    }

    $stmt->execute();
    $orders = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取订单明细数据
    $orderIds = [];
    foreach ($orders as $order) {
        $orderIds[] = $order['id'];
    }

    $orderItems = [];
    if (!empty($orderIds)) {
        $placeholders = str_repeat('?,', count($orderIds) - 1) . '?';
        $orderItemsQuery = "
            SELECT 
                soi.*,
                p.name AS product_name,
                p.type AS product_type,
                so.order_date
            FROM 
                sales_order_items soi
            JOIN 
                sales_orders so ON soi.sales_order_id = so.id
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                soi.sales_order_id IN ($placeholders)
            ORDER BY 
                so.order_date DESC, soi.id
        ";

        $stmt = $pdo->prepare($orderItemsQuery);
        $stmt->execute($orderIds);
        $orderItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // 获取统计数据
    // 1. 总销售收入
    $stmt = $pdo->prepare("
        SELECT 
            SUM(total_amount) AS total_revenue
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN :start_date AND :end_date
            AND status != 'cancelled'
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $totalRevenue = $stmt->fetch(PDO::FETCH_ASSOC)['total_revenue'] ?: 0;

    // 2. 订单数量
    $stmt = $pdo->prepare("
        SELECT 
            COUNT(*) AS order_count
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN :start_date AND :end_date
            AND status != 'cancelled'
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $orderCount = $stmt->fetch(PDO::FETCH_ASSOC)['order_count'] ?: 0;

    // 3. 产品销售统计 - 按产品统计销售额
    $stmt = $pdo->prepare("
        SELECT 
            p.id,
            p.name AS product_name,
            SUM(soi.quantity) AS total_quantity,
            SUM(soi.item_total_amount) AS total_amount,
            COUNT(DISTINCT so.id) AS order_count,
            AVG(soi.unit_price) AS avg_price
        FROM 
            sales_order_items soi
        JOIN 
            sales_orders so ON soi.sales_order_id = so.id
        JOIN 
            products p ON soi.product_id = p.id
        WHERE 
            so.order_date BETWEEN :start_date AND :end_date
            AND so.status != 'cancelled'
        GROUP BY 
            p.id
        ORDER BY 
            total_amount DESC
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $productStats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 4. 客户销售统计 - 按客户统计销售额
    $stmt = $pdo->prepare("
        SELECT 
            c.id,
            c.name AS customer_name,
            c.type AS customer_type,
            c.region,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS total_amount,
            MAX(so.order_date) AS latest_order_date
        FROM 
            sales_orders so
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            so.order_date BETWEEN :start_date AND :end_date
            AND so.status != 'cancelled'
        GROUP BY 
            c.id
        ORDER BY 
            total_amount DESC
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $customerStats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 5. 区域销售统计 - 按区域统计销售额
    $stmt = $pdo->prepare("
        SELECT 
            c.region,
            COUNT(DISTINCT c.id) AS customer_count,
            COUNT(so.id) AS order_count,
            SUM(so.total_amount) AS total_amount
        FROM 
            sales_orders so
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            so.order_date BETWEEN :start_date AND :end_date
            AND so.status != 'cancelled'
            AND c.region IS NOT NULL
        GROUP BY 
            c.region
        ORDER BY 
            total_amount DESC
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $regionStats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 6. 月度销售趋势 - 按月统计销售额
    $stmt = $pdo->prepare("
        SELECT 
            DATE_FORMAT(order_date, '%Y-%m') AS month,
            COUNT(*) AS order_count,
            SUM(total_amount) AS total_amount
        FROM 
            sales_orders
        WHERE 
            order_date BETWEEN :start_date AND :end_date
            AND status != 'cancelled'
        GROUP BY 
            DATE_FORMAT(order_date, '%Y-%m')
        ORDER BY 
            month
    ");
    $stmt->bindParam(':start_date', $start_date);
    $stmt->bindParam(':end_date', $end_date);
    $stmt->execute();
    $monthlyStats = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有客户，用于筛选器
    $stmt = $pdo->query("
        SELECT id, name FROM customers ORDER BY name
    ");
    $customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有区域，用于筛选器
    $stmt = $pdo->query("
        SELECT DISTINCT region FROM customers WHERE region IS NOT NULL ORDER BY region
    ");
    $regions = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有销售渠道，用于筛选器
    $stmt = $pdo->query("
        SELECT id, name FROM sales_channels ORDER BY name
    ");
    $channels = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    $error = "查询失败: " . $e->getMessage();
}

// 计算月度趋势图表数据
$months = [];
$monthlyRevenue = [];
$monthlyOrderCount = [];

foreach ($monthlyStats as $stat) {
    $months[] = $stat['month'];
    $monthlyRevenue[] = $stat['total_amount'];
    $monthlyOrderCount[] = $stat['order_count'];
}

// 计算产品图表数据
$productNames = [];
$productRevenue = [];

foreach (array_slice($productStats, 0, 5) as $stat) {
    $productNames[] = $stat['product_name'];
    $productRevenue[] = $stat['total_amount'];
}

// 计算区域图表数据
$regionNames = [];
$regionRevenue = [];

foreach ($regionStats as $stat) {
    $regionNames[] = $stat['region'];
    $regionRevenue[] = $stat['total_amount'];
}

// 客户类型映射
$customerTypeMap = [
    'wholesale' => '批发',
    'retail' => '零售',
    'distributor' => '经销商',
    'ecommerce' => '电商'
];

// 订单状态映射
$orderStatusMap = [
    'draft' => '草稿',
    'confirmed' => '已确认',
    'processing' => '处理中',
    'partially_shipped' => '部分发货',
    'shipped' => '已发货',
    'delivered' => '已送达',
    'cancelled' => '已取消'
];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>销售收入统计 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <script src="https://cdn.bootcdn.net/ajax/libs/Chart.js/3.9.1/chart.min.js"></script>
    <style>
        .container {
            max-width: 1000px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .form-group button {
            width: 60%;
            padding: 12px;
            background-color: #3498db;
            color: #fff;
            border: none;
            border-radius: 4px;
            font-size: 16px;
            cursor: pointer;
        }

        .dashboard {
            display: grid;
            grid-template-columns: repeat(2, 1fr);
            gap: 20px;
            margin-bottom: 30px;
        }

        .card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            text-align: center;
        }

        .card h3 {
            color: #555;
            font-size: 16px;
            margin-bottom: 10px;
        }

        .card .value {
            color: #2c3e50;
            font-size: 24px;
            font-weight: bold;
        }

        .card .subtext {
            color: #7f8c8d;
            font-size: 14px;
            margin-top: 5px;
        }

        .chart-container {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            padding-bottom: 90px;
            margin-bottom: 30px;
            min-height: 450px;
        }

        .chart-grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
            margin-bottom: 30px;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
            border-bottom: none;
            border-radius: 4px 4px 0 0;
            margin-right: 5px;
        }

        .tab.active {
            background: #fff;
            border-color: #ddd;
            border-bottom: 1px solid #fff;
            margin-bottom: -1px;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }

        .filter-container {
            background: #f9f9f9;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(150px, 1fr));
            gap: 10px;
            align-items: end;
        }

        .filter-container .form-group {
            margin-bottom: 0;
        }

        .filter-container button {
            padding: 10px;
        }

        .data-table th:nth-child(4),
        .data-table th:nth-child(5),
        .data-table th:nth-child(6) {
            text-align: right;
        }

        .data-table td:nth-child(4),
        .data-table td:nth-child(5),
        .data-table td:nth-child(6) {
            text-align: right;
        }

        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>销售收入统计</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <!-- 筛选面板 -->
        <form method="GET" action="" class="filter-container">
            <div class="form-group">
                <label for="start_date">开始日期</label>
                <input type="date" id="start_date" name="start_date" value="<?= $start_date ?>">
            </div>
            <div class="form-group">
                <label for="end_date">结束日期</label>
                <input type="date" id="end_date" name="end_date" value="<?= $end_date ?>">
            </div>
            <div class="form-group">
                <label for="filter_type">筛选类型</label>
                <select id="filter_type" name="filter_type">
                    <option value="">不筛选</option>
                    <option value="customer" <?= $filter_type == 'customer' ? 'selected' : '' ?>>按客户</option>
                    <option value="region" <?= $filter_type == 'region' ? 'selected' : '' ?>>按区域</option>
                    <option value="channel" <?= $filter_type == 'channel' ? 'selected' : '' ?>>按销售渠道</option>
                </select>
            </div>
            <div class="form-group">
                <label for="filter_value">筛选值</label>
                <select id="filter_value" name="filter_value">
                    <option value="">请选择</option>
                    <!-- 选项将通过JS动态加载 -->
                </select>
            </div>
            <div class="form-group">
                <button type="submit" class="btn-primary">应用筛选</button>
                <a href="?start_date=<?= date('Y-m-d', strtotime('-12 months')) ?>&end_date=<?= date('Y-m-d') ?>" class="btn-secondary">重置</a>
            </div>
        </form>

        <?php if (empty($error)): ?>
            <!-- 销售概览 -->
            <section class="dashboard">
                <div class="card">
                    <h3>总销售收入</h3>
                    <div class="value"><?= number_format($totalRevenue, 2) ?> 元</div>
                    <div class="subtext"><?= $start_date ?> 至 <?= $end_date ?></div>
                </div>
                <div class="card">
                    <h3>订单数量</h3>
                    <div class="value"><?= $orderCount ?></div>
                    <div class="subtext">平均订单金额: <?= $orderCount > 0 ? number_format($totalRevenue / $orderCount, 2) : 0 ?> 元</div>
                </div>
            </section>

            <!-- 销售图表 -->
            <section class="chart-grid">
                <div class="chart-container">
                    <h2>月度销售趋势</h2>
                    <canvas id="monthlyRevenueChart"></canvas>
                </div>
                <div class="chart-container">
                    <h2>产品销售分布</h2>
                    <canvas id="productRevenueChart"></canvas>
                </div>
            </section>

            <!-- 销售详情标签页 -->
            <section class="tab-container">
                <div class="tabs">
                    <div class="tab active" onclick="openTab(event, 'productTab')">按产品统计</div>
                    <div class="tab" onclick="openTab(event, 'customerTab')">按客户统计</div>
                    <div class="tab" onclick="openTab(event, 'regionTab')">按区域统计</div>
                </div>

                <!-- 按产品统计标签内容 -->
                <div id="productTab" class="tab-content active">
                    <h2>产品销售统计</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>销售订单数</th>
                                <th>销售数量</th>
                                <th>平均单价(元)</th>
                                <th>销售总额(元)</th>
                                <th>占比</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($productStats) > 0): ?>
                                <?php foreach ($productStats as $stat): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($stat['product_name']) ?></td>
                                        <td><?= $stat['order_count'] ?></td>
                                        <td><?= number_format($stat['total_quantity'], 2) ?></td>
                                        <td><?= number_format($stat['avg_price'], 2) ?></td>
                                        <td><?= number_format($stat['total_amount'], 2) ?></td>
                                        <td><?= $totalRevenue > 0 ? number_format($stat['total_amount'] / $totalRevenue * 100, 2) : 0 ?>%</td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无销售产品数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 按客户统计标签内容 -->
                <div id="customerTab" class="tab-content">
                    <h2>客户销售统计</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>客户名称</th>
                                <th>客户类型</th>
                                <th>区域</th>
                                <th>订单数</th>
                                <th>销售总额(元)</th>
                                <th>占比</th>
                                <th>最近订单日期</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($customerStats) > 0): ?>
                                <?php foreach ($customerStats as $stat): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($stat['customer_name']) ?></td>
                                        <td><?= isset($customerTypeMap[$stat['customer_type']]) ? $customerTypeMap[$stat['customer_type']] : $stat['customer_type'] ?></td>
                                        <td><?= htmlspecialchars($stat['region']) ?></td>
                                        <td><?= $stat['order_count'] ?></td>
                                        <td><?= number_format($stat['total_amount'], 2) ?></td>
                                        <td><?= $totalRevenue > 0 ? number_format($stat['total_amount'] / $totalRevenue * 100, 2) : 0 ?>%</td>
                                        <td><?= $stat['latest_order_date'] ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无客户销售数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 按区域统计标签内容 -->
                <div id="regionTab" class="tab-content">
                    <h2>区域销售统计</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>区域</th>
                                <th>客户数量</th>
                                <th>订单数量</th>
                                <th>销售总额(元)</th>
                                <th>占比</th>
                                <th>平均客户贡献(元)</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($regionStats) > 0): ?>
                                <?php foreach ($regionStats as $stat): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($stat['region']) ?></td>
                                        <td><?= $stat['customer_count'] ?></td>
                                        <td><?= $stat['order_count'] ?></td>
                                        <td><?= number_format($stat['total_amount'], 2) ?></td>
                                        <td><?= $totalRevenue > 0 ? number_format($stat['total_amount'] / $totalRevenue * 100, 2) : 0 ?>%</td>
                                        <td><?= $stat['customer_count'] > 0 ? number_format($stat['total_amount'] / $stat['customer_count'], 2) : 0 ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无区域销售数据</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </section>
        <?php endif; ?>
    </div>

    <script>
        // 标签页切换
        function openTab(evt, tabId) {
            var i, tabContent, tabLinks;

            // 隐藏所有标签页内容
            tabContent = document.getElementsByClassName("tab-content");
            for (i = 0; i < tabContent.length; i++) {
                tabContent[i].className = tabContent[i].className.replace(" active", "");
            }

            // 移除所有标签的active状态
            tabLinks = document.getElementsByClassName("tab");
            for (i = 0; i < tabLinks.length; i++) {
                tabLinks[i].className = tabLinks[i].className.replace(" active", "");
            }

            // 显示当前标签页并添加active状态
            document.getElementById(tabId).className += " active";
            evt.currentTarget.className += " active";
        }

        // 筛选器值动态加载
        const filterType = document.getElementById('filter_type');
        const filterValue = document.getElementById('filter_value');

        // 客户选项
        const customers = <?= json_encode($customers) ?>;

        // 区域选项
        const regions = <?= json_encode($regions) ?>;

        // 销售渠道选项
        const channels = <?= json_encode($channels) ?>;

        filterType.addEventListener('change', function() {
            // 清空现有选项
            filterValue.innerHTML = '<option value="">请选择</option>';

            // 根据选择的筛选类型填充选项
            if (this.value === 'customer') {
                customers.forEach(customer => {
                    const option = document.createElement('option');
                    option.value = customer.id;
                    option.textContent = customer.name;
                    if (customer.id == "<?= $filter_value ?>") {
                        option.selected = true;
                    }
                    filterValue.appendChild(option);
                });
            } else if (this.value === 'region') {
                regions.forEach(region => {
                    const option = document.createElement('option');
                    option.value = region.region;
                    option.textContent = region.region;
                    if (region.region == "<?= $filter_value ?>") {
                        option.selected = true;
                    }
                    filterValue.appendChild(option);
                });
            } else if (this.value === 'channel') {
                channels.forEach(channel => {
                    const option = document.createElement('option');
                    option.value = channel.id;
                    option.textContent = channel.name;
                    if (channel.id == "<?= $filter_value ?>") {
                        option.selected = true;
                    }
                    filterValue.appendChild(option);
                });
            }
        });

        // 初始化筛选器选项
        window.onload = function() {
            filterType.dispatchEvent(new Event('change'));
        };

        // 销售图表
        document.addEventListener('DOMContentLoaded', function() {
            <?php if (empty($error)): ?>
                // 月度销售趋势图表
                var monthlyCtx = document.getElementById('monthlyRevenueChart').getContext('2d');
                var monthlyRevenueChart = new Chart(monthlyCtx, {
                    type: 'line',
                    data: {
                        labels: <?= json_encode($months) ?>,
                        datasets: [{
                                label: '月度销售额(元)',
                                data: <?= json_encode($monthlyRevenue) ?>,
                                borderColor: 'rgba(54, 162, 235, 1)',
                                backgroundColor: 'rgba(54, 162, 235, 0.1)',
                                borderWidth: 2,
                                fill: true,
                                yAxisID: 'y'
                            },
                            {
                                label: '月度订单数',
                                data: <?= json_encode($monthlyOrderCount) ?>,
                                borderColor: 'rgba(255, 99, 132, 1)',
                                backgroundColor: 'rgba(255, 99, 132, 0.1)',
                                borderWidth: 2,
                                fill: false,
                                yAxisID: 'y1'
                            }
                        ]
                    },
                    options: {
                        responsive: true,
                        maintainAspectRatio: false,
                        scales: {
                            y: {
                                type: 'linear',
                                display: true,
                                position: 'left',
                                title: {
                                    display: true,
                                    text: '销售额(元)'
                                }
                            },
                            y1: {
                                type: 'linear',
                                display: true,
                                position: 'right',
                                title: {
                                    display: true,
                                    text: '订单数'
                                },
                                grid: {
                                    drawOnChartArea: false
                                }
                            }
                        }
                    }
                });

                // 产品销售分布图表
                var productCtx = document.getElementById('productRevenueChart').getContext('2d');
                var productRevenueChart = new Chart(productCtx, {
                    type: 'pie',
                    data: {
                        labels: <?= json_encode($productNames) ?>,
                        datasets: [{
                            label: '销售额(元)',
                            data: <?= json_encode($productRevenue) ?>,
                            backgroundColor: [
                                'rgba(255, 99, 132, 0.7)',
                                'rgba(54, 162, 235, 0.7)',
                                'rgba(255, 206, 86, 0.7)',
                                'rgba(75, 192, 192, 0.7)',
                                'rgba(153, 102, 255, 0.7)'
                            ],
                            borderColor: [
                                'rgba(255, 99, 132, 1)',
                                'rgba(54, 162, 235, 1)',
                                'rgba(255, 206, 86, 1)',
                                'rgba(75, 192, 192, 1)',
                                'rgba(153, 102, 255, 1)'
                            ],
                            borderWidth: 1
                        }]
                    },
                    options: {
                        responsive: true,
                        maintainAspectRatio: false,
                        plugins: {
                            legend: {
                                position: 'right',
                                labels: {
                                    boxWidth: 20,
                                    padding: 15
                                }
                            },
                            tooltip: {
                                callbacks: {
                                    label: function(context) {
                                        var label = context.label || '';
                                        var value = context.parsed || 0;
                                        var total = context.dataset.data.reduce((a, b) => a + b, 0);
                                        var percentage = Math.round((value / total) * 100);

                                        return label + ': ' + value.toLocaleString() + ' 元 (' + percentage + '%)';
                                    }
                                }
                            }
                        }
                    }
                });
            <?php endif; ?>
        });
    </script>
</body>

</html>