<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取搜索参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$location_id = isset($_GET['location_id']) ? (int)$_GET['location_id'] : 0;
$low_stock_only = isset($_GET['low_stock_only']) ? (bool)$_GET['low_stock_only'] : false;

// 获取所有仓库位置
try {
    $stmt = $pdo->query("
        SELECT id, name, type, temperature_controlled, humidity_controlled
        FROM storage_locations
        ORDER BY name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 查询原料库存
try {
    $query = "
        SELECT 
            i.id,
            p.id AS product_id,
            p.name AS product_name,
            p.specification,
            i.quantity_on_hand,
            i.unit,
            i.low_stock_threshold,
            sl.id AS location_id,
            sl.name AS location_name,
            sl.temperature_controlled,
            sl.humidity_controlled,
            i.last_updated
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        JOIN 
            storage_locations sl ON i.storage_location_id = sl.id
        WHERE 
            p.type = 'raw'
    ";

    $params = [];

    // 添加搜索条件
    if (!empty($search)) {
        $query .= " AND (p.name LIKE ? OR p.specification LIKE ?)";
        $params[] = "%$search%";
        $params[] = "%$search%";
    }

    // 按仓库位置筛选
    if ($location_id > 0) {
        $query .= " AND sl.id = ?";
        $params[] = $location_id;
    }

    // 只显示低库存
    if ($low_stock_only) {
        $query .= " AND i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0";
    }

    $query .= " ORDER BY (CASE WHEN i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0 THEN 0 ELSE 1 END), p.name";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $rawMaterials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取原料库存失败：" . $e->getMessage();
}

// 获取最近的原料入库记录
try {
    $stmt = $pdo->query("
        SELECT 
            mr.id,
            mr.received_date,
            p.name AS product_name,
            mr.received_quantity,
            p.unit,
            mr.batch_number,
            mr.quality_check_result,
            u.username AS inspector_name,
            sl.name AS location_name,
            po.order_number
        FROM 
            material_receiving mr
        JOIN 
            products p ON mr.product_id = p.id
        LEFT JOIN 
            users u ON mr.inspector_id = u.id
        LEFT JOIN 
            storage_locations sl ON mr.storage_location_id = sl.id
        LEFT JOIN 
            purchase_order_items poi ON mr.purchase_order_item_id = poi.id
        LEFT JOIN 
            purchase_orders po ON poi.purchase_order_id = po.id
        WHERE 
            p.type = 'raw'
        ORDER BY 
            mr.received_date DESC
        LIMIT 10
    ");
    $recentReceipts = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取入库记录失败：" . $e->getMessage();
}

// 质检结果对应的显示文本和样式
$qualityResultDisplay = [
    'passed' => ['text' => '合格', 'class' => '已完成'],
    'failed' => ['text' => '不合格', 'class' => '待处理'],
    'pending' => ['text' => '待检验', 'class' => '进行中']
];

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>原料库存管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .low-stock {
            background-color: #fff3cd !important;
            color: #856404;
        }

        .search-container {
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            gap: 15px;
            margin-bottom: 20px;
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
        }

        .search-container input,
        .search-container select {
            padding: 8px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            flex-grow: 1;
        }

        .search-container button {
            padding: 8px 16px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .search-container button:hover {
            background-color: #2980b9;
        }

        .checkbox-container {
            display: flex;
            align-items: center;
            gap: 5px;
        }

        .checkbox-container input[type="checkbox"] {
            width: auto;
            flex-grow: 0;
        }

        .receipt-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .batch-info {
            font-size: 16px;
            font-weight: bold;
            color: #2c3e50;
            margin-bottom: 10px;
            display: flex;
            justify-content: space-between;
        }

        .receipt-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 5px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
        }

        .stock-status {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-sufficient {
            background-color: #28a745;
        }

        .status-low {
            background-color: #ffc107;
            color: #212529;
        }

        .status-critical {
            background-color: #dc3545;
        }

        .tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border-radius: 4px 4px 0 0;
            margin-right: 5px;
        }

        .tab.active {
            background-color: #3498db;
            color: white;
            border: 1px solid #3498db;
            border-bottom: none;
        }

        .tab:not(.active) {
            background-color: #f8f9fa;
            border: 1px solid #ddd;
            border-bottom: none;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>原料库存管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 标签页导航 -->
        <div class="tabs">
            <div class="tab active" onclick="switchTab('inventory-tab')">库存一览</div>
            <div class="tab" onclick="switchTab('recent-tab')">最近入库记录</div>
        </div>

        <!-- 库存一览标签页 -->
        <div id="inventory-tab" class="tab-content active">
            <!-- 搜索筛选 -->
            <div class="search-container">
                <form method="GET" action="raw_material_inventory.php">
                    <input type="text" name="search" placeholder="搜索原料名称或规格" value="<?= htmlspecialchars($search) ?>">

                    <select name="location_id">
                        <option value="0">所有仓库位置</option>
                        <?php foreach ($locations as $loc): ?>
                            <option value="<?= $loc['id'] ?>" <?= $location_id == $loc['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($loc['name']) ?>
                                <?= $loc['temperature_controlled'] ? ' (温控)' : '' ?>
                                <?= $loc['humidity_controlled'] ? ' (湿控)' : '' ?>
                            </option>
                        <?php endforeach; ?>
                    </select>

                    <div class="checkbox-container">
                        <input type="checkbox" id="low_stock_only" name="low_stock_only" value="1" <?= $low_stock_only ? 'checked' : '' ?>>
                        <label for="low_stock_only">只显示低库存</label>
                    </div>

                    <button type="submit">筛选</button>
                    <button type="button" onclick="window.location.href='raw_material_inventory.php'">重置</button>
                </form>
            </div>

            <!-- 原料库存表格 -->
            <div class="table-container">
                <?php if (empty($rawMaterials)): ?>
                    <div class="empty-state">
                        <p>暂无原料库存数据</p>
                    </div>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>原料名称</th>
                                <th>规格</th>
                                <th>库存数量</th>
                                <th>单位</th>
                                <th>存放位置</th>
                                <th>库存状态</th>
                                <th>最后更新时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($rawMaterials as $material): ?>
                                <?php
                                $isLowStock = false;
                                $stockStatus = '';
                                $stockStatusClass = '';

                                if ($material['low_stock_threshold'] > 0) {
                                    if ($material['quantity_on_hand'] <= $material['low_stock_threshold'] * 0.5) {
                                        $isLowStock = true;
                                        $stockStatus = '库存紧张';
                                        $stockStatusClass = 'status-critical';
                                    } elseif ($material['quantity_on_hand'] <= $material['low_stock_threshold']) {
                                        $isLowStock = true;
                                        $stockStatus = '库存不足';
                                        $stockStatusClass = 'status-low';
                                    } else {
                                        $stockStatus = '库存充足';
                                        $stockStatusClass = 'status-sufficient';
                                    }
                                } else {
                                    $stockStatus = '未设置预警';
                                    $stockStatusClass = 'status-critical';
                                }
                                ?>
                                <tr class="<?= $isLowStock ? 'low-stock' : '' ?>">
                                    <td><?= htmlspecialchars($material['product_name']) ?></td>
                                    <td><?= htmlspecialchars($material['specification'] ?? '-') ?></td>
                                    <td><?= number_format($material['quantity_on_hand'], 2) ?></td>
                                    <td><?= htmlspecialchars($material['unit']) ?></td>
                                    <td>
                                        <?= htmlspecialchars($material['location_name']) ?>
                                        <?php if ($material['temperature_controlled']): ?>
                                            <span title="温控仓库"><i class="fas fa-thermometer-half"></i></span>
                                        <?php endif; ?>
                                        <?php if ($material['humidity_controlled']): ?>
                                            <span title="湿控仓库"><i class="fas fa-tint"></i></span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <span class="stock-status <?= $stockStatusClass ?>"><?= $stockStatus ?></span>
                                        <?php if ($material['low_stock_threshold'] > 0): ?>
                                            <br>
                                            <small>预警值: <?= $material['low_stock_threshold'] ?> <?= $material['unit'] ?></small>
                                        <?php endif; ?>
                                    </td>
                                    <td><?= date('Y-m-d H:i', strtotime($material['last_updated'])) ?></td>
                                    <td>
                                        <a href="inventory_history.php?product_id=<?= $material['product_id'] ?>" class="btn-link">查看记录</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        </div>

        <!-- 最近入库记录标签页 -->
        <div id="recent-tab" class="tab-content">
            <h3>最近原料入库记录</h3>

            <?php if (empty($recentReceipts)): ?>
                <div class="empty-state">
                    <p>暂无入库记录</p>
                </div>
            <?php else: ?>
                <?php foreach ($recentReceipts as $receipt): ?>
                    <?php
                    $qualityInfo = $qualityResultDisplay[$receipt['quality_check_result']] ?? ['text' => $receipt['quality_check_result'], 'class' => ''];
                    ?>
                    <div class="receipt-card">
                        <div class="batch-info">
                            <div>批次: <?= htmlspecialchars($receipt['batch_number']) ?></div>
                            <div class="status-tag <?= $qualityInfo['class'] ?>"><?= $qualityInfo['text'] ?></div>
                        </div>
                        <div class="receipt-info">
                            <div class="info-item">
                                <span class="info-label">物料：</span>
                                <?= htmlspecialchars($receipt['product_name']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">数量：</span>
                                <?= number_format($receipt['received_quantity'], 2) ?> <?= htmlspecialchars($receipt['unit']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">采购订单：</span>
                                <?= htmlspecialchars($receipt['order_number'] ?? '直接入库') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">入库日期：</span>
                                <?= date('Y-m-d H:i', strtotime($receipt['received_date'])) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">存放位置：</span>
                                <?= htmlspecialchars($receipt['location_name'] ?? '未指定') ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">检验员：</span>
                                <?= htmlspecialchars($receipt['inspector_name'] ?? '未指定') ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.3/js/all.min.js"></script>
    <script>
        function switchTab(tabId) {
            // 隐藏所有标签页内容
            document.querySelectorAll('.tab-content').forEach(content => {
                content.classList.remove('active');
            });

            // 取消选中所有标签
            document.querySelectorAll('.tab').forEach(tab => {
                tab.classList.remove('active');
            });

            // 显示选中的标签页内容
            document.getElementById(tabId).classList.add('active');

            // 选中对应的标签
            event.currentTarget.classList.add('active');
        }
    </script>
</body>

</html>