<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取发货记录ID
$shipment_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($shipment_id <= 0) {
    header("Location: finished_goods_inventory.php");
    exit;
}

$error_message = '';
$success_message = '';
$shipment_info = null;
$carriers = [];

// 获取物流公司列表
try {
    $stmt = $pdo->query("
        SELECT id, name, service_type
        FROM carriers
        WHERE is_active = 1
        ORDER BY name
    ");
    $carriers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error_message = "获取物流公司列表失败：" . $e->getMessage();
}

// 获取发货记录信息
try {
    $stmt = $pdo->prepare("
        SELECT 
            sh.*,
            so.order_number,
            so.customer_id,
            c.name AS customer_name,
            c.contact_person,
            c.phone,
            c.address
        FROM 
            shipments sh
        JOIN 
            sales_orders so ON sh.sales_order_id = so.id
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 
            sh.id = ?
    ");
    $stmt->execute([$shipment_id]);
    $shipment_info = $stmt->fetch();

    if (!$shipment_info) {
        $error_message = "未找到相关发货记录";
    }

    // 获取订单项目
    $stmt = $pdo->prepare("
        SELECT 
            soi.*,
            p.name AS product_name,
            p.specification,
            p.unit
        FROM 
            sales_order_items soi
        JOIN 
            products p ON soi.product_id = p.id
        WHERE 
            soi.sales_order_id = ?
    ");
    $stmt->execute([$shipment_info['sales_order_id']]);
    $shipment_info['items'] = $stmt->fetchAll();
} catch (Exception $e) {
    $error_message = $e->getMessage();
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $status = trim($_POST['status'] ?? '');
        $carrier_id = (int)($_POST['carrier_id'] ?? 0);
        $tracking_number = trim($_POST['tracking_number'] ?? '');
        $estimated_delivery_date = trim($_POST['estimated_delivery_date'] ?? '');
        $actual_delivery_date = trim($_POST['actual_delivery_date'] ?? '');
        $shipping_cost = (float)($_POST['shipping_cost'] ?? 0);
        $notes = trim($_POST['notes'] ?? '');

        // 验证数据
        if (empty($status)) {
            throw new Exception("请选择发货状态");
        }

        // 如果状态为已发货或运输中，需要物流公司和单号
        if (in_array($status, ['shipped', 'in_transit']) && $carrier_id <= 0) {
            throw new Exception("请选择物流公司");
        }

        if (in_array($status, ['shipped', 'in_transit']) && empty($tracking_number)) {
            throw new Exception("请输入物流单号");
        }

        // 如果状态为已送达，需要实际送达日期
        if ($status === 'delivered' && empty($actual_delivery_date)) {
            throw new Exception("请选择实际送达日期");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 准备更新数据
        $updateFields = [
            'status' => $status,
            'notes' => $notes ?: $shipment_info['notes']
        ];

        // 条件更新其他字段
        if ($carrier_id > 0) {
            $updateFields['carrier_id'] = $carrier_id;
        }

        if (!empty($tracking_number)) {
            $updateFields['tracking_number'] = $tracking_number;
        }

        if (!empty($estimated_delivery_date)) {
            $updateFields['estimated_delivery_date'] = $estimated_delivery_date;
        }

        if (!empty($actual_delivery_date)) {
            $updateFields['actual_delivery_date'] = $actual_delivery_date;
        }

        if ($shipping_cost > 0) {
            $updateFields['shipping_cost'] = $shipping_cost;
        }

        // 如果状态由未发货变为已发货或运输中，更新发货日期
        if ($shipment_info['status'] === 'ready_to_ship' && in_array($status, ['shipped', 'in_transit'])) {
            $updateFields['shipment_date'] = date('Y-m-d H:i:s');
        }

        // 构建SQL更新语句
        $updateQuery = "UPDATE shipments SET ";
        $updateParams = [];

        foreach ($updateFields as $field => $value) {
            $updateQuery .= "$field = ?, ";
            $updateParams[] = $value;
        }

        // 添加最后更新时间
        $updateQuery .= "updated_at = CURRENT_TIMESTAMP WHERE id = ?";
        $updateParams[] = $shipment_id;

        // 执行更新
        $stmt = $pdo->prepare($updateQuery);
        $stmt->execute($updateParams);

        // 如果状态发生变化，更新销售订单状态
        if ($status !== $shipment_info['status']) {
            // 如果是已送达状态，更新销售订单为已送达
            if ($status === 'delivered') {
                $stmt = $pdo->prepare("
                    UPDATE sales_orders
                    SET status = 'delivered'
                    WHERE id = ?
                ");
                $stmt->execute([$shipment_info['sales_order_id']]);
            }

            // 记录操作日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, 'shipment', ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                "更新发货状态",
                $shipment_id,
                "发货单号：{$shipment_info['shipment_number']}，状态由 {$shipment_info['status']} 更新为 {$status}",
                $_SERVER['REMOTE_ADDR']
            ]);
        }

        // 提交事务
        $pdo->commit();

        $success_message = "发货信息更新成功";

        // 刷新发货记录信息
        $stmt = $pdo->prepare("
            SELECT 
                sh.*,
                so.order_number,
                so.customer_id,
                c.name AS customer_name,
                c.contact_person,
                c.phone,
                c.address
            FROM 
                shipments sh
            JOIN 
                sales_orders so ON sh.sales_order_id = so.id
            JOIN 
                customers c ON so.customer_id = c.id
            WHERE 
                sh.id = ?
        ");
        $stmt->execute([$shipment_id]);
        $shipment_info = $stmt->fetch();

        // 获取订单项目
        $stmt = $pdo->prepare("
            SELECT 
                soi.*,
                p.name AS product_name,
                p.specification,
                p.unit
            FROM 
                sales_order_items soi
            JOIN 
                products p ON soi.product_id = p.id
            WHERE 
                soi.sales_order_id = ?
        ");
        $stmt->execute([$shipment_info['sales_order_id']]);
        $shipment_info['items'] = $stmt->fetchAll();
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $error_message = $e->getMessage();
    }
}

// 发货状态映射
$shipmentStatusOptions = [
    'ready_to_ship' => '待发货',
    'shipped' => '已发货',
    'in_transit' => '运输中',
    'delivered' => '已送达',
    'failed' => '配送失败',
    'cancelled' => '已取消'
];

// 当前状态的中文名称
$currentStatus = $shipmentStatusOptions[$shipment_info['status']] ?? $shipment_info['status'];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>更新发货信息</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .container {
            max-width: 800px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .section {
            margin-bottom: 20px;
            padding: 15px;
            border: 1px solid #e9ecef;
            border-radius: 8px;
            background-color: #f8f9fa;
        }

        .section-title {
            font-size: 18px;
            font-weight: bold;
            margin-bottom: 15px;
            color: #495057;
            border-bottom: 1px solid #dee2e6;
            padding-bottom: 8px;
        }

        .info-grid {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 10px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
            margin-right: 5px;
        }

        .status-tag {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .待处理,
        .已取消,
        .配送失败 {
            background: #f39c12;
            color: white;
        }

        .已发货,
        .运输中 {
            background: #3498db;
            color: white;
        }

        .已送达 {
            background: #2ecc71;
            color: white;
        }

        .form-row {
            margin-bottom: 15px;
        }

        .form-row label {
            display: block;
            font-weight: bold;
            margin-bottom: 5px;
        }

        .form-row input,
        .form-row select,
        .form-row textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ced4da;
            border-radius: 4px;
        }

        .form-row textarea {
            height: 100px;
            resize: vertical;
        }

        .alert {
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        .btn-container {
            display: flex;
            justify-content: space-between;
            margin-top: 20px;
        }

        .btn {
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
            text-decoration: none;
            display: inline-block;
            text-align: center;
        }

        .btn-primary {
            background-color: #3498db;
            color: white;
        }

        .btn-secondary {
            background-color: #6c757d;
            color: white;
        }

        .btn-primary:hover {
            background-color: #2980b9;
        }

        .btn-secondary:hover {
            background-color: #5a6268;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 15px;
        }

        table th,
        table td {
            padding: 8px;
            border: 1px solid #ddd;
            text-align: left;
        }

        table th {
            background-color: #f5f5f5;
        }

        table tr:nth-child(even) {
            background-color: #f9f9f9;
        }

        .status-field-container {
            margin-bottom: 15px;
        }

        .conditional-fields {
            padding: 15px;
            border: 1px solid #e9ecef;
            border-radius: 8px;
            margin-top: 15px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>更新发货信息</h2>

        <?php if ($success_message): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>

        <?php if ($error_message): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <!-- 基本信息展示区域 -->
        <div class="section">
            <div class="section-title">发货基本信息</div>
            <div class="info-grid">
                <div class="info-item">
                    <span class="info-label">发货单号:</span>
                    <?= htmlspecialchars($shipment_info['shipment_number']) ?>
                </div>
                <div class="info-item">
                    <span class="info-label">订单编号:</span>
                    <?= htmlspecialchars($shipment_info['order_number']) ?>
                </div>
                <div class="info-item">
                    <span class="info-label">客户名称:</span>
                    <?= htmlspecialchars($shipment_info['customer_name']) ?>
                </div>
                <div class="info-item">
                    <span class="info-label">当前状态:</span>
                    <span class="status-tag <?= $currentStatus ?>"><?= $currentStatus ?></span>
                </div>
                <div class="info-item">
                    <span class="info-label">联系人:</span>
                    <?= htmlspecialchars($shipment_info['contact_person'] ?: '无') ?>
                </div>
                <div class="info-item">
                    <span class="info-label">联系电话:</span>
                    <?= htmlspecialchars($shipment_info['phone'] ?: '无') ?>
                </div>
            </div>
            <div class="info-item">
                <span class="info-label">收货地址:</span>
                <div><?= htmlspecialchars($shipment_info['address'] ?: '无') ?></div>
            </div>
        </div>

        <!-- 发货商品列表 -->
        <?php if (!empty($shipment_info['items'])): ?>
            <div class="section">
                <div class="section-title">发货商品</div>
                <table>
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>规格</th>
                            <th>单位</th>
                            <th>订单数量</th>
                            <th>发货数量</th>
                            <th>单价</th>
                            <th>金额</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($shipment_info['items'] as $item): ?>
                            <?php
                            $amount = $item['quantity'] * $item['unit_price'] * (1 - $item['discount_rate']);
                            ?>
                            <tr>
                                <td><?= htmlspecialchars($item['product_name']) ?></td>
                                <td><?= htmlspecialchars($item['specification'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($item['unit']) ?></td>
                                <td><?= number_format($item['quantity'], 2) ?></td>
                                <td><?= number_format($item['shipped_quantity'], 2) ?></td>
                                <td><?= number_format($item['unit_price'], 2) ?> 元</td>
                                <td><?= number_format($amount, 2) ?> 元</td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        <?php endif; ?>

        <!-- 更新发货信息表单 -->
        <form method="post" action="">
            <div class="section">
                <div class="section-title">更新发货状态</div>

                <div class="status-field-container">
                    <label for="status">发货状态</label>
                    <select name="status" id="status" required onchange="toggleConditionalFields()">
                        <?php foreach ($shipmentStatusOptions as $value => $label): ?>
                            <option value="<?= $value ?>" <?= $shipment_info['status'] === $value ? 'selected' : '' ?>><?= $label ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div id="shipping-fields" class="conditional-fields" style="display:none;">
                    <div class="form-row">
                        <label for="carrier_id">物流公司</label>
                        <select name="carrier_id" id="carrier_id">
                            <option value="">请选择物流公司</option>
                            <?php foreach ($carriers as $carrier): ?>
                                <option value="<?= $carrier['id'] ?>" <?= $shipment_info['carrier_id'] == $carrier['id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($carrier['name']) ?>
                                    <?= $carrier['service_type'] ? '(' . htmlspecialchars($carrier['service_type']) . ')' : '' ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-row">
                        <label for="tracking_number">物流单号</label>
                        <input type="text" id="tracking_number" name="tracking_number" value="<?= htmlspecialchars($shipment_info['tracking_number'] ?: '') ?>" placeholder="请输入物流单号">
                    </div>

                    <div class="form-row">
                        <label for="estimated_delivery_date">预计送达日期</label>
                        <input type="date" id="estimated_delivery_date" name="estimated_delivery_date" value="<?= $shipment_info['estimated_delivery_date'] ? date('Y-m-d', strtotime($shipment_info['estimated_delivery_date'])) : '' ?>">
                    </div>

                    <div class="form-row">
                        <label for="shipping_cost">物流费用 (元)</label>
                        <input type="number" id="shipping_cost" name="shipping_cost" value="<?= $shipment_info['shipping_cost'] ?: '' ?>" step="0.01" min="0">
                    </div>
                </div>

                <div id="delivery-fields" class="conditional-fields" style="display:none;">
                    <div class="form-row">
                        <label for="actual_delivery_date">实际送达日期</label>
                        <input type="date" id="actual_delivery_date" name="actual_delivery_date" value="<?= $shipment_info['actual_delivery_date'] ? date('Y-m-d', strtotime($shipment_info['actual_delivery_date'])) : date('Y-m-d') ?>">
                    </div>
                </div>

                <div class="form-row">
                    <label for="notes">备注说明</label>
                    <textarea name="notes" id="notes" placeholder="请输入备注信息"><?= htmlspecialchars($shipment_info['notes'] ?: '') ?></textarea>
                </div>
            </div>

            <div class="btn-container">
                <a href="outbound_detail.php?shipment_id=<?= $shipment_id ?>" class="btn btn-secondary">返回详情</a>
                <button type="submit" class="btn btn-primary">保存更新</button>
            </div>
        </form>
    </div>

    <script>
        // 初始化页面时根据选择的状态显示/隐藏相应字段
        document.addEventListener('DOMContentLoaded', function() {
            toggleConditionalFields();
        });

        function toggleConditionalFields() {
            const status = document.getElementById('status').value;
            const shippingFields = document.getElementById('shipping-fields');
            const deliveryFields = document.getElementById('delivery-fields');
            const carrierIdField = document.getElementById('carrier_id');
            const trackingNumberField = document.getElementById('tracking_number');
            const actualDeliveryDateField = document.getElementById('actual_delivery_date');

            // 重置所有字段的必填属性
            carrierIdField.required = false;
            trackingNumberField.required = false;
            actualDeliveryDateField.required = false;

            // 隐藏所有条件字段
            shippingFields.style.display = 'none';
            deliveryFields.style.display = 'none';

            // 根据状态显示相应字段
            if (status === 'shipped' || status === 'in_transit') {
                shippingFields.style.display = 'block';
                carrierIdField.required = true;
                trackingNumberField.required = true;
            }

            if (status === 'delivered') {
                shippingFields.style.display = 'block';
                deliveryFields.style.display = 'block';
                actualDeliveryDateField.required = true;
            }
        }
    </script>
</body>

</html>