<?php
// login.php
require_once './config.php';

// 已登录用户重定向
if (isset($_SESSION['user_id'])) {
    header("Location: home.php");
    exit;
}

$error = '';
$username = '';
$title = '果易管(FruitEase)系统'; // 直接定义系统名称

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = trim($_POST['username'] ?? '');
    $password = $_POST['password'] ?? '';

    if (empty($username) || empty($password)) {
        $error = '用户名和密码不能为空';
    } else {
        try {
            $stmt = $pdo->prepare("
                SELECT id as user_id, username, password_hash, role_id, is_active 
                FROM users 
                WHERE username = :username
                LIMIT 1
            ");
            $stmt->execute([':username' => $username]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($user && $user['is_active'] && password_verify($password, $user['password_hash'])) {
                // 获取角色信息
                $stmt = $pdo->prepare("SELECT name FROM roles WHERE id = :role_id");
                $stmt->execute([':role_id' => $user['role_id']]);
                $role = $stmt->fetchColumn();

                $_SESSION['user_id'] = $user['user_id'];
                $_SESSION['username'] = $user['username'];
                $_SESSION['role'] = $role;
                $_SESSION['role_id'] = $user['role_id'];

                // 记录登录时间
                $stmt = $pdo->prepare("
                    UPDATE users 
                    SET last_login_at = CURRENT_TIMESTAMP 
                    WHERE id = :user_id
                ");
                $stmt->execute([':user_id' => $user['user_id']]);

                // 记录登录操作到日志
                $stmt = $pdo->prepare("
                    INSERT INTO activity_log 
                    (user_id, username, action, target_type, target_id, ip_address) 
                    VALUES (:user_id, :username, '用户登录', 'user', :target_id, :ip_address)
                ");
                $stmt->execute([
                    ':user_id' => $user['user_id'],
                    ':username' => $user['username'],
                    ':target_id' => $user['user_id'],
                    ':ip_address' => $_SERVER['REMOTE_ADDR']
                ]);

                header("Location: home.php");
                exit;
            } else {
                $error = '用户名或密码错误，或账号已被禁用';
            }
        } catch (PDOException $e) {
            $error = '系统错误，请稍后再试';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>登录 - <?= $title ?></title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .login-container {
            max-width: 400px;
            margin: 5rem auto;
            padding: 2rem;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 0 15px rgba(0, 0, 0, 0.1);
        }

        body {
            background: #f8f9fa;
            min-height: 100vh;
            display: flex;
            align-items: center;
        }

        .brand-title {
            color: #2c3e50;
            font-weight: 600;
            letter-spacing: 1px;
        }

        /* 新增标题容器定位 */
        .title-container {
            position: relative;
            margin-top: 60px;
            /* 为logo预留空间 */
        }

        /* 精准定位logo在标题正上方 */
        .login-logo {
            position: absolute;
            top: -85px;
            /* 精确控制logo与标题间距 */
            left: 50%;
            transform: translateX(-50%);
            width: 80px;
            /* 适当缩小logo尺寸 */
            height: 80px;
            border: 3px solid #fff;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
            border-radius: 50%;
            z-index: 1;
        }

        /* 调整登录框间距 */
        .login-container {
            margin: 30px auto;
            padding: 40px 30px 20px;
        }
    </style>

</head>

<body>
    <div class="container">
        <img src="./img/icon.png" alt="系统logo" class="login-logo">
        <div class="login-container">
            <div class="title-container">
                <img src="./img/icon.png" alt="系统logo" class="login-logo">
                <div class="text-center mb-4">
                    <h2 class="brand-title">果易管系统<br>(FruitEase)</h2>
                    <p class="text-muted mt-2">凉果深加工企业信息化管理系统</p>
                </div>
            </div>

            <?php if ($error): ?>
                <div class="alert alert-danger"><?= $error ?></div>
            <?php endif; ?>

            <form method="post">
                <div class="form-group">
                    <label>用户名</label>
                    <input type="text"
                        name="username"
                        class="form-control"
                        value="<?= $username ?>"
                        required
                        autofocus>
                </div>

                <div class="form-group">
                    <label>密码</label>
                    <input type="password"
                        name="password"
                        class="form-control"
                        required>
                </div>

                <button type="submit" class="btn btn-primary btn-block">
                    登录系统
                </button>
            </form>
        </div>
    </div>
</body>

</html>