<?php
// production/production_analytics.php
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 设置时间范围筛选
$time_range = $_GET['time_range'] ?? 'month'; // 默认查看最近一个月
$end_date = date('Y-m-d');

switch ($time_range) {
    case 'week':
        $start_date = date('Y-m-d', strtotime('-1 week'));
        $title = '最近一周';
        break;
    case 'month':
        $start_date = date('Y-m-d', strtotime('-1 month'));
        $title = '最近一个月';
        break;
    case 'quarter':
        $start_date = date('Y-m-d', strtotime('-3 month'));
        $title = '最近三个月';
        break;
    case 'year':
        $start_date = date('Y-m-d', strtotime('-1 year'));
        $title = '最近一年';
        break;
    case 'custom':
        $start_date = $_GET['start_date'] ?? date('Y-m-d', strtotime('-1 month'));
        $end_date = $_GET['end_date'] ?? date('Y-m-d');
        $title = "自定义：{$start_date} 至 {$end_date}";
        break;
    default:
        $start_date = date('Y-m-d', strtotime('-1 month'));
        $title = '最近一个月';
}

// 查询指定时间范围内的已完成批次
$stmt = $pdo->prepare("
    SELECT 
        pb.id,
        pb.batch_number,
        pb.start_time,
        pb.end_time,
        pb.quantity_planned,
        pb.quantity_produced,
        pb.estimated_cost,
        pb.actual_cost,
        p.name AS product_name,
        p.type AS product_type,
        p.unit
    FROM production_batches pb
    JOIN products p ON pb.product_id = p.id
    WHERE pb.status IN ('completed', 'quality_check', 'stocked')
    AND pb.start_time IS NOT NULL
    AND pb.end_time IS NOT NULL
    AND pb.start_time BETWEEN ? AND ?
    ORDER BY pb.end_time DESC
");
$stmt->execute([$start_date, $end_date . ' 23:59:59']);
$batches = $stmt->fetchAll();

// 计算总计数据
$totalBatches = count($batches);
$totalPlannedQuantity = 0;
$totalProducedQuantity = 0;
$totalProductionTime = 0; // 以小时计
$avgYieldRate = 0;
$avgCycleTime = 0;

$productionData = []; // 用于图表展示
$yieldRateData = []; // 用于成品率图表

if ($totalBatches > 0) {
    foreach ($batches as $batch) {
        // 计算生产时间（小时）
        $startTime = new DateTime($batch['start_time']);
        $endTime = new DateTime($batch['end_time']);
        $interval = $startTime->diff($endTime);
        $productionHours = $interval->days * 24 + $interval->h + $interval->i / 60;

        $totalProductionTime += $productionHours;

        // 计算计划量和实际产量
        $plannedQuantity = floatval($batch['quantity_planned']);
        $producedQuantity = floatval($batch['quantity_produced'] ?? 0);

        $totalPlannedQuantity += $plannedQuantity;
        $totalProducedQuantity += $producedQuantity;

        // 计算单批次成品率
        $yieldRate = ($plannedQuantity > 0) ? ($producedQuantity / $plannedQuantity * 100) : 0;

        // 添加到图表数据
        $productionData[] = [
            'batch' => $batch['batch_number'],
            'product' => $batch['product_name'],
            'cycle_time' => round($productionHours, 1),
            'planned' => $plannedQuantity,
            'produced' => $producedQuantity,
            'yield' => round($yieldRate, 1)
        ];

        $yieldRateData[] = [
            'batch' => $batch['batch_number'],
            'yield' => round($yieldRate, 1)
        ];
    }

    // 计算平均值
    $avgYieldRate = ($totalPlannedQuantity > 0) ? ($totalProducedQuantity / $totalPlannedQuantity * 100) : 0;
    $avgCycleTime = $totalProductionTime / $totalBatches;
}

// 按产品类型统计
$stmt = $pdo->prepare("
    SELECT 
        p.id,
        p.name AS product_name,
        p.type AS product_type,
        COUNT(pb.id) AS batch_count,
        SUM(pb.quantity_planned) AS total_planned,
        SUM(pb.quantity_produced) AS total_produced,
        AVG(TIMESTAMPDIFF(HOUR, pb.start_time, pb.end_time)) AS avg_hours
    FROM production_batches pb
    JOIN products p ON pb.product_id = p.id
    WHERE pb.status IN ('completed', 'quality_check', 'stocked')
    AND pb.start_time IS NOT NULL
    AND pb.end_time IS NOT NULL
    AND pb.start_time BETWEEN ? AND ?
    GROUP BY p.id
    ORDER BY batch_count DESC
");
$stmt->execute([$start_date, $end_date . ' 23:59:59']);
$productStats = $stmt->fetchAll();

// 按月统计生产效率趋势
$stmt = $pdo->prepare("
    SELECT 
        DATE_FORMAT(pb.end_time, '%Y-%m') AS month,
        COUNT(pb.id) AS batch_count,
        SUM(pb.quantity_planned) AS total_planned,
        SUM(pb.quantity_produced) AS total_produced,
        AVG(TIMESTAMPDIFF(HOUR, pb.start_time, pb.end_time)) AS avg_hours
    FROM production_batches pb
    WHERE pb.status IN ('completed', 'quality_check', 'stocked')
    AND pb.start_time IS NOT NULL
    AND pb.end_time IS NOT NULL
    AND pb.start_time BETWEEN ? AND ?
    GROUP BY DATE_FORMAT(pb.end_time, '%Y-%m')
    ORDER BY month
");
$stmt->execute([$start_date, $end_date . ' 23:59:59']);
$monthlyStats = $stmt->fetchAll();

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产效率分析 - <?= title ?></title>
    <link href="https://lib.baomitu.com/twitter-bootstrap/4.6.0/css/bootstrap.min.css" rel="stylesheet">
    <!-- 使用单一稳定的国内CDN源 -->
    <script src="https://lib.baomitu.com/Chart.js/2.9.4/Chart.min.js"></script>
    <style>
        .analysis-container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .stats-card {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
        }

        .stats-value {
            font-size: 24px;
            font-weight: bold;
            color: #2c3e50;
        }

        .stats-label {
            color: #7f8c8d;
            font-size: 14px;
        }

        .chart-container {
            margin-bottom: 30px;
            height: 300px;
        }

        .filter-form {
            margin-bottom: 20px;
            padding: 15px;
            background-color: #f8f9fa;
            border-radius: 8px;
        }

        .good-rate {
            color: #2ecc71;
        }

        .warning-rate {
            color: #f39c12;
        }

        .bad-rate {
            color: #e74c3c;
        }

        .table th {
            background-color: #f5f5f5;
        }

        /* 按钮样式 */
        .btn-primary {
            background-color: #3498db;
            border-color: #2980b9;
        }

        .btn-primary:hover {
            background-color: #2980b9;
            border-color: #2980b9;
        }

        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        /* 添加返回按钮样式 */
        .back-btn {
            margin-bottom: 20px;
            display: inline-block;
            padding: 8px 15px;
            background-color: #f5f5f5;
            color: #333;
            text-decoration: none;
            border-radius: 4px;
            border: 1px solid #ddd;
        }

        .back-btn:hover {
            background-color: #e9e9e9;
            text-decoration: none;
            color: #333;
        }
    </style>
</head>

<body>
    <div class="container">
        <!-- <a href="../index.php" class="back-btn">
            <i class="fas fa-arrow-left"></i> 返回首页
        </a> -->

        <h2 class="text-center mb-4">生产效率分析</h2>

        <!-- 筛选表单 -->
        <div class="filter-form">
            <form method="get" class="row">
                <div class="col-md-3">
                    <label for="time_range">时间范围</label>
                    <select name="time_range" id="time_range" class="form-control" onchange="toggleCustomDates()">
                        <option value="week" <?= $time_range == 'week' ? 'selected' : '' ?>>最近一周</option>
                        <option value="month" <?= $time_range == 'month' ? 'selected' : '' ?>>最近一个月</option>
                        <option value="quarter" <?= $time_range == 'quarter' ? 'selected' : '' ?>>最近三个月</option>
                        <option value="year" <?= $time_range == 'year' ? 'selected' : '' ?>>最近一年</option>
                        <option value="custom" <?= $time_range == 'custom' ? 'selected' : '' ?>>自定义时间范围</option>
                    </select>
                </div>

                <div class="col-md-3 custom-date" style="<?= $time_range == 'custom' ? '' : 'display: none;' ?>">
                    <label for="start_date">开始日期</label>
                    <input type="date" name="start_date" id="start_date" class="form-control" value="<?= $start_date ?>">
                </div>

                <div class="col-md-3 custom-date" style="<?= $time_range == 'custom' ? '' : 'display: none;' ?>">
                    <label for="end_date">结束日期</label>
                    <input type="date" name="end_date" id="end_date" class="form-control" value="<?= $end_date ?>">
                </div>

                <div class="col-md-3 d-flex align-items-end">
                    <button type="submit" class="btn btn-primary">应用筛选</button>
                </div>
            </form>
        </div>

        <!-- 分析结果标题 -->
        <h3 class="mt-4 mb-3"><?= $title ?> 生产效率分析</h3>

        <!-- 汇总数据卡片 -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="stats-card">
                    <div class="stats-value"><?= $totalBatches ?></div>
                    <div class="stats-label">生产批次数</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <div class="stats-value <?= getYieldRateClass($avgYieldRate) ?>"><?= number_format($avgYieldRate, 1) ?>%</div>
                    <div class="stats-label">平均成品率</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <div class="stats-value"><?= number_format($avgCycleTime, 1) ?> 小时</div>
                    <div class="stats-label">平均生产周期</div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <div class="stats-value <?= getLossRateClass(100 - $avgYieldRate) ?>"><?= number_format(100 - $avgYieldRate, 1) ?>%</div>
                    <div class="stats-label">平均损耗率</div>
                </div>
            </div>
        </div>

        <!-- 图表部分 -->
        <div class="row">
            <!-- 成品率图表 -->
            <div class="col-md-6">
                <div class="chart-container">
                    <canvas id="yieldRateChart"></canvas>
                </div>
            </div>

            <!-- 生产周期图表 -->
            <div class="col-md-6">
                <div class="chart-container">
                    <canvas id="cycleTimeChart"></canvas>
                </div>
            </div>
        </div>

        <!-- 按产品统计表格 -->
        <h4 class="mt-4 mb-3">各产品生产效率统计</h4>
        <div class="table-responsive">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>产品名称</th>
                        <th>产品类型</th>
                        <th>批次数</th>
                        <th>计划总量</th>
                        <th>实际产量</th>
                        <th>成品率</th>
                        <th>平均生产周期</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($productStats)): ?>
                        <tr>
                            <td colspan="7" class="text-center">暂无数据</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($productStats as $stat): ?>
                            <?php
                            $yieldRate = ($stat['total_planned'] > 0) ?
                                ($stat['total_produced'] / $stat['total_planned'] * 100) : 0;
                            $productType = $stat['product_type'] == 'semi-finished' ? '半成品' : '成品';
                            ?>
                            <tr>
                                <td><?= htmlspecialchars($stat['product_name']) ?></td>
                                <td><?= $productType ?></td>
                                <td><?= $stat['batch_count'] ?></td>
                                <td><?= number_format($stat['total_planned'], 2) ?></td>
                                <td><?= number_format($stat['total_produced'], 2) ?></td>
                                <td class="<?= getYieldRateClass($yieldRate) ?>"><?= number_format($yieldRate, 1) ?>%</td>
                                <td><?= number_format($stat['avg_hours'], 1) ?> 小时</td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- 批次明细表格 -->
        <h4 class="mt-4 mb-3">生产批次明细</h4>
        <div class="table-responsive">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>批次号</th>
                        <th>产品名称</th>
                        <th>开始时间</th>
                        <th>结束时间</th>
                        <th>生产周期</th>
                        <th>计划数量</th>
                        <th>实际产量</th>
                        <th>成品率</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($batches)): ?>
                        <tr>
                            <td colspan="8" class="text-center">暂无数据</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($batches as $batch): ?>
                            <?php
                            $startTime = new DateTime($batch['start_time']);
                            $endTime = new DateTime($batch['end_time']);
                            $interval = $startTime->diff($endTime);
                            $hours = $interval->days * 24 + $interval->h;
                            $minutes = $interval->i;
                            $cycleTime = $hours . "小时" . ($minutes > 0 ? $minutes . "分钟" : "");

                            $yieldRate = ($batch['quantity_planned'] > 0) ?
                                ($batch['quantity_produced'] / $batch['quantity_planned'] * 100) : 0;
                            ?>
                            <tr>
                                <td><?= htmlspecialchars($batch['batch_number']) ?></td>
                                <td><?= htmlspecialchars($batch['product_name']) ?></td>
                                <td><?= date('Y-m-d H:i', strtotime($batch['start_time'])) ?></td>
                                <td><?= date('Y-m-d H:i', strtotime($batch['end_time'])) ?></td>
                                <td><?= $cycleTime ?></td>
                                <td><?= number_format($batch['quantity_planned'], 2) ?> <?= $batch['unit'] ?></td>
                                <td><?= number_format($batch['quantity_produced'], 2) ?> <?= $batch['unit'] ?></td>
                                <td class="<?= getYieldRateClass($yieldRate) ?>"><?= number_format($yieldRate, 1) ?>%</td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 切换自定义日期字段的显示状态
        function toggleCustomDates() {
            const timeRange = document.getElementById('time_range').value;
            const customDateFields = document.querySelectorAll('.custom-date');

            customDateFields.forEach(field => {
                field.style.display = (timeRange === 'custom') ? 'block' : 'none';
            });
        }

        // 初始化成品率图表
        const yieldRateCtx = document.getElementById('yieldRateChart').getContext('2d');
        const yieldRateChart = new Chart(yieldRateCtx, {
            type: 'bar',
            data: {
                labels: <?= json_encode(array_column($yieldRateData, 'batch')) ?>,
                datasets: [{
                    label: '成品率 (%)',
                    data: <?= json_encode(array_column($yieldRateData, 'yield')) ?>,
                    backgroundColor: '#3498db',
                    borderColor: '#2980b9',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        max: 100,
                        title: {
                            display: true,
                            text: '成品率 (%)'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '生产批次'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '批次成品率统计'
                    }
                }
            }
        });

        // 初始化生产周期图表
        const cycleTimeCtx = document.getElementById('cycleTimeChart').getContext('2d');
        const cycleTimeChart = new Chart(cycleTimeCtx, {
            type: 'bar',
            data: {
                labels: <?= json_encode(array_column($productionData, 'batch')) ?>,
                datasets: [{
                    label: '生产周期 (小时)',
                    data: <?= json_encode(array_column($productionData, 'cycle_time')) ?>,
                    backgroundColor: '#2ecc71',
                    borderColor: '#27ae60',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                scales: {
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: '生产周期 (小时)'
                        }
                    },
                    x: {
                        title: {
                            display: true,
                            text: '生产批次'
                        }
                    }
                },
                plugins: {
                    title: {
                        display: true,
                        text: '批次生产周期统计'
                    }
                }
            }
        });
    </script>

    <?php
    // 根据成品率返回样式类名
    function getYieldRateClass($rate)
    {
        if ($rate >= 95) {
            return 'good-rate';
        } elseif ($rate >= 85) {
            return 'warning-rate';
        } else {
            return 'bad-rate';
        }
    }

    // 根据损耗率返回样式类名
    function getLossRateClass($rate)
    {
        if ($rate <= 5) {
            return 'good-rate';
        } elseif ($rate <= 15) {
            return 'warning-rate';
        } else {
            return 'bad-rate';
        }
    }
    ?>
</body>

</html>