<?php
// certification_management.php - 认证管理功能
// 管理HACCP、ISO22000、绿色食品认证等认证
session_start();
require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查认证表是否存在，如果不存在则创建
try {
    // 检查表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'certifications'");
    $tableExists = $stmt->rowCount() > 0;

    if (!$tableExists) {
        // 创建认证表
        $pdo->exec("
            CREATE TABLE `certifications` (
              `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '认证ID',
              `name` VARCHAR(100) NOT NULL COMMENT '认证名称',
              `certification_type` ENUM('HACCP', 'ISO22000', 'GREEN_FOOD', 'OTHER') NOT NULL COMMENT '认证类型',
              `certificate_number` VARCHAR(100) NOT NULL COMMENT '证书编号',
              `issue_date` DATE NOT NULL COMMENT '颁发日期',
              `expiry_date` DATE NOT NULL COMMENT '到期日期',
              `issuing_authority` VARCHAR(255) NOT NULL COMMENT '颁发机构',
              `status` ENUM('valid', 'expired', 'pending', 'revoked') NOT NULL DEFAULT 'valid' COMMENT '状态',
              `file_path` VARCHAR(255) DEFAULT NULL COMMENT '证书文件路径',
              `notes` TEXT DEFAULT NULL COMMENT '备注',
              `created_by_user_id` INT UNSIGNED DEFAULT NULL COMMENT '创建人ID',
              `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
              PRIMARY KEY (`id`),
              KEY `idx_cert_type` (`certification_type`),
              KEY `idx_cert_status` (`status`),
              KEY `idx_cert_expiry` (`expiry_date`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='认证管理表';
        ");

        // 添加一些示例数据
        $pdo->exec("
            INSERT INTO `certifications` 
            (`name`, `certification_type`, `certificate_number`, `issue_date`, `expiry_date`, `issuing_authority`, `status`, `notes`, `created_by_user_id`) 
            VALUES 
            ('HACCP食品安全管理体系认证', 'HACCP', 'HC2024001', '2024-01-15', '2027-01-14', '中国质量认证中心', 'valid', '覆盖主要生产线和产品', 1),
            ('ISO22000食品安全管理体系认证', 'ISO22000', 'ISO22K-202405', '2024-05-01', '2027-04-30', '国际标准化组织授权机构', 'valid', '全面质量管理体系认证', 1),
            ('绿色食品认证-芒果干系列', 'GREEN_FOOD', 'GF20230012', '2023-06-10', '2025-06-09', '中国绿色食品发展中心', 'valid', '适用于芒果干系列产品', 1);
        ");
    }
} catch (PDOException $e) {
    $tableError = "创建认证表失败: " . $e->getMessage();
}

// 处理表单提交
$successMessage = '';
$errorMessage = '';

// 处理添加或更新认证表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    $action = $_POST['action'];

    // 通用字段验证和准备
    $certFields = [
        'name' => $_POST['name'] ?? '',
        'certification_type' => $_POST['certification_type'] ?? '',
        'certificate_number' => $_POST['certificate_number'] ?? '',
        'issue_date' => $_POST['issue_date'] ?? '',
        'expiry_date' => $_POST['expiry_date'] ?? '',
        'issuing_authority' => $_POST['issuing_authority'] ?? '',
        'status' => $_POST['status'] ?? 'valid',
        'notes' => $_POST['notes'] ?? null,
        'created_by_user_id' => $_SESSION['user_id']
    ];

    // 验证必填字段
    $requiredFields = ['name', 'certification_type', 'certificate_number', 'issue_date', 'expiry_date', 'issuing_authority', 'status'];
    $missingFields = [];

    foreach ($requiredFields as $field) {
        if (empty($certFields[$field])) {
            $missingFields[] = $field;
        }
    }

    if (!empty($missingFields)) {
        $errorMessage = "请填写所有必填字段: " . implode(', ', $missingFields);
    } else {
        // 文件上传处理
        $uploadedFile = $_FILES['certificate_file'] ?? null;
        $filePath = null;
        $keepExistingFile = isset($_POST['keep_file']) && $_POST['keep_file'] == 1;

        if ($action == 'create' || ($action == 'update' && !$keepExistingFile && !empty($uploadedFile['name']))) {
            // 处理文件上传
            if (!empty($uploadedFile['name'])) {
                $allowedExtensions = ['pdf', 'jpg', 'jpeg', 'png'];
                $fileExtension = strtolower(pathinfo($uploadedFile['name'], PATHINFO_EXTENSION));

                if (!in_array($fileExtension, $allowedExtensions)) {
                    $errorMessage = "不支持的文件格式。允许的格式: PDF, JPG, JPEG, PNG";
                } elseif ($uploadedFile['size'] > 10485760) { // 10MB限制
                    $errorMessage = "文件大小超过限制。最大允许: 10MB";
                } else {
                    // 创建上传目录
                    $uploadDir = '../uploads/certifications/';
                    if (!is_dir($uploadDir)) {
                        mkdir($uploadDir, 0777, true);
                    }

                    // 生成唯一文件名
                    $newFileName = uniqid() . '_' . $certFields['certification_type'] . '_' . date('Ymd') . '.' . $fileExtension;
                    $targetFilePath = $uploadDir . $newFileName;

                    if (move_uploaded_file($uploadedFile['tmp_name'], $targetFilePath)) {
                        $filePath = 'uploads/certifications/' . $newFileName;
                    } else {
                        $errorMessage = "文件上传失败，请重试";
                    }
                }
            }
        }

        if (empty($errorMessage)) {
            try {
                if ($action == 'create') {
                    // 添加新认证
                    $sql = "
                        INSERT INTO certifications 
                        (name, certification_type, certificate_number, issue_date, expiry_date, issuing_authority, status, file_path, notes, created_by_user_id)
                        VALUES 
                        (:name, :certification_type, :certificate_number, :issue_date, :expiry_date, :issuing_authority, :status, :file_path, :notes, :created_by_user_id)
                    ";
                    $stmt = $pdo->prepare($sql);
                    $stmt->bindParam(':file_path', $filePath);

                    foreach ($certFields as $field => $value) {
                        $stmt->bindParam(':' . $field, $certFields[$field]);
                    }

                    $stmt->execute();
                    $successMessage = "认证记录添加成功";

                    // 记录到活动日志
                    $logStmt = $pdo->prepare("
                        INSERT INTO activity_log 
                        (user_id, username, action, target_type, target_id, ip_address) 
                        VALUES (:user_id, :username, '添加认证', 'certification', :target_id, :ip_address)
                    ");
                    $lastId = $pdo->lastInsertId();
                    $logStmt->execute([
                        ':user_id' => $_SESSION['user_id'],
                        ':username' => $_SESSION['username'],
                        ':target_id' => $lastId,
                        ':ip_address' => $_SERVER['REMOTE_ADDR']
                    ]);
                } elseif ($action == 'update' && isset($_POST['id'])) {
                    // 更新现有认证
                    $id = (int)$_POST['id'];

                    // 如果保留现有文件，获取当前文件路径
                    if ($keepExistingFile) {
                        $stmt = $pdo->prepare("SELECT file_path FROM certifications WHERE id = ?");
                        $stmt->execute([$id]);
                        $currentFilePath = $stmt->fetchColumn();
                        $filePath = $currentFilePath;
                    }

                    $sql = "
                        UPDATE certifications 
                        SET name = :name,
                            certification_type = :certification_type,
                            certificate_number = :certificate_number,
                            issue_date = :issue_date,
                            expiry_date = :expiry_date,
                            issuing_authority = :issuing_authority,
                            status = :status,
                            file_path = :file_path,
                            notes = :notes
                        WHERE id = :id
                    ";

                    $stmt = $pdo->prepare($sql);
                    $stmt->bindParam(':file_path', $filePath);
                    $stmt->bindParam(':id', $id);

                    foreach ($certFields as $field => $value) {
                        if ($field != 'created_by_user_id') { // 不更新创建者
                            $stmt->bindParam(':' . $field, $certFields[$field]);
                        }
                    }

                    $stmt->execute();
                    $successMessage = "认证记录更新成功";

                    // 记录到活动日志
                    $logStmt = $pdo->prepare("
                        INSERT INTO activity_log 
                        (user_id, username, action, target_type, target_id, ip_address) 
                        VALUES (:user_id, :username, '更新认证', 'certification', :target_id, :ip_address)
                    ");
                    $logStmt->execute([
                        ':user_id' => $_SESSION['user_id'],
                        ':username' => $_SESSION['username'],
                        ':target_id' => $id,
                        ':ip_address' => $_SERVER['REMOTE_ADDR']
                    ]);
                }

                // 成功后重定向到认证管理主页
                header("Location: certification_management.php?success=" . urlencode($successMessage));
                exit;
            } catch (PDOException $e) {
                $errorMessage = "操作失败: " . $e->getMessage();
            }
        }
    }
}

// 删除认证
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $id = (int)$_GET['delete'];
    try {
        $stmt = $pdo->prepare("SELECT file_path FROM certifications WHERE id = ?");
        $stmt->execute([$id]);
        $cert = $stmt->fetch();

        // 删除证书文件
        if ($cert && !empty($cert['file_path']) && file_exists('../' . $cert['file_path'])) {
            unlink('../' . $cert['file_path']);
        }

        // 删除记录
        $stmt = $pdo->prepare("DELETE FROM certifications WHERE id = ?");
        $stmt->execute([$id]);

        if ($stmt->rowCount() > 0) {
            // 记录到活动日志
            $logStmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, ip_address) 
                VALUES (:user_id, :username, '删除认证', 'certification', :target_id, :ip_address)
            ");
            $logStmt->execute([
                ':user_id' => $_SESSION['user_id'],
                ':username' => $_SESSION['username'],
                ':target_id' => $id,
                ':ip_address' => $_SERVER['REMOTE_ADDR']
            ]);

            $successMessage = "认证记录已成功删除";
        }
    } catch (PDOException $e) {
        $errorMessage = "删除认证记录失败: " . $e->getMessage();
    }
}

// 获取URL中的成功消息
if (isset($_GET['success'])) {
    $successMessage = $_GET['success'];
}

// 获取所有认证记录
$certifications = [];
try {
    $stmt = $pdo->query("
        SELECT c.*, u.username as created_by_username
        FROM certifications c
        LEFT JOIN users u ON c.created_by_user_id = u.id
        ORDER BY 
        CASE 
            WHEN c.status = 'valid' AND c.expiry_date <= DATE_ADD(CURDATE(), INTERVAL 60 DAY) THEN 1
            WHEN c.status = 'valid' THEN 2
            WHEN c.status = 'pending' THEN 3
            WHEN c.status = 'expired' THEN 4
            ELSE 5
        END,
        c.expiry_date ASC
    ");
    $certifications = $stmt->fetchAll();
} catch (PDOException $e) {
    $errorMessage = "获取认证记录失败: " . $e->getMessage();
}

// 计算即将到期的认证数量
$expiringCount = 0;
$today = new DateTime();
foreach ($certifications as $cert) {
    $expiryDate = new DateTime($cert['expiry_date']);
    $diff = $today->diff($expiryDate);
    if ($cert['status'] == 'valid' && $diff->days <= 60 && $expiryDate > $today) {
        $expiringCount++;
    }
}

// 辅助函数 - 获取认证类型中文名称
function getCertificationType($type)
{
    $types = [
        'HACCP' => 'HACCP认证',
        'ISO22000' => 'ISO22000认证',
        'GREEN_FOOD' => '绿色食品认证',
        'OTHER' => '其他认证'
    ];
    return $types[$type] ?? $type;
}

// 辅助函数 - 获取认证状态中文名称
function getCertificationStatus($status)
{
    $statuses = [
        'valid' => '有效',
        'expired' => '已过期',
        'pending' => '待审核',
        'revoked' => '已撤销'
    ];
    return $statuses[$status] ?? $status;
}

// 辅助函数 - 获取认证状态对应的CSS类
function getStatusClass($status)
{
    $classes = [
        'valid' => 'success',
        'expired' => 'danger',
        'pending' => 'warning',
        'revoked' => 'secondary'
    ];
    return $classes[$status] ?? 'secondary';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>认证管理 - <?= title ?></title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    <style>
        .certificate-card {
            margin-bottom: 20px;
            transition: all 0.3s;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }

        .certificate-card:hover {
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
            transform: translateY(-2px);
        }

        .certificate-header {
            padding: 15px;
            border-bottom: 1px solid #eee;
        }

        .certificate-body {
            padding: 15px;
        }

        .certificate-footer {
            padding: 10px 15px;
            background-color: #f8f9fa;
            border-top: 1px solid #eee;
        }

        .expiring-soon {
            background-color: #fff3cd;
            border-left: 4px solid #ffc107;
        }

        .expired {
            background-color: #f8d7da;
            border-left: 4px solid #dc3545;
        }

        .certificate-icon {
            font-size: 2rem;
            margin-right: 15px;
        }

        .certificate-badge {
            position: absolute;
            top: 10px;
            right: 10px;
            padding: 5px 10px;
            border-radius: 20px;
            font-size: 0.8rem;
            font-weight: bold;
        }

        .tab-pane {
            padding: 20px 0;
        }

        .nav-tabs .nav-link {
            border-radius: 0;
            font-weight: 500;
        }

        .nav-tabs .nav-link.active {
            border-bottom: 3px solid #007bff;
            color: #007bff;
        }

        .reminder-box {
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
            background-color: #fff3cd;
            border: 1px solid #ffeeba;
        }

        .cert-property {
            margin-bottom: 8px;
        }

        .cert-property-label {
            font-weight: bold;
            color: #6c757d;
        }

        .file-link {
            display: inline-block;
            padding: 5px 10px;
            background-color: #f8f9fa;
            border: 1px solid #ddd;
            border-radius: 4px;
            margin-top: 5px;
        }

        .expiry-date {
            font-weight: bold;
        }

        .days-left {
            font-size: 0.9rem;
            margin-left: 5px;
        }
    </style>
    <!-- <link rel="stylesheet" href="style.css"> -->
</head>

<body>
    <div class="container-fluid mt-4">
        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0"><i class="fas fa-certificate mr-2"></i>认证管理</h5>
                    </div>
                    <div class="card-body">
                        <?php if (isset($tableError)): ?>
                            <div class="alert alert-danger"><?= $tableError ?></div>
                        <?php endif; ?>

                        <?php if ($successMessage): ?>
                            <div class="alert alert-success"><?= $successMessage ?></div>
                        <?php endif; ?>

                        <?php if ($errorMessage): ?>
                            <div class="alert alert-danger"><?= $errorMessage ?></div>
                        <?php endif; ?>

                        <?php if ($expiringCount > 0): ?>
                            <div class="reminder-box">
                                <h5><i class="fas fa-exclamation-triangle mr-2"></i>认证到期提醒</h5>
                                <p>您有 <strong><?= $expiringCount ?></strong> 个认证将在近期到期，请及时处理更新手续。</p>
                            </div>
                        <?php endif; ?>

                        <ul class="nav nav-tabs mb-4" id="certificationTabs" role="tablist">
                            <li class="nav-item">
                                <a class="nav-link active" id="all-tab" data-toggle="tab" href="#all" role="tab">
                                    所有认证 <span class="badge badge-primary"><?= count($certifications) ?></span>
                                </a>
                            </li>
                            <li class="nav-item">
                                <a class="nav-link" id="haccp-tab" data-toggle="tab" href="#haccp" role="tab">
                                    HACCP认证
                                </a>
                            </li>
                            <li class="nav-item">
                                <a class="nav-link" id="iso22000-tab" data-toggle="tab" href="#iso22000" role="tab">
                                    ISO22000认证
                                </a>
                            </li>
                            <li class="nav-item">
                                <a class="nav-link" id="green-food-tab" data-toggle="tab" href="#green-food" role="tab">
                                    绿色食品认证
                                </a>
                            </li>
                            <li class="nav-item ml-auto">
                                <button type="button" class="btn btn-success" id="addCertButton" data-toggle="modal" data-target="#addCertModal">
                                    <i class="fas fa-plus mr-1"></i>添加认证
                                </button>
                            </li>
                        </ul>

                        <div class="tab-content" id="certificationTabsContent">
                            <div class="tab-pane fade show active" id="all" role="tabpanel">
                                <?php if (empty($certifications)): ?>
                                    <div class="alert alert-info">
                                        <i class="fas fa-info-circle mr-2"></i>暂无认证记录，请点击"添加认证"按钮添加
                                    </div>
                                <?php else: ?>
                                    <div class="row">
                                        <?php foreach ($certifications as $cert):
                                            $expiryDate = new DateTime($cert['expiry_date']);
                                            $diff = $today->diff($expiryDate);
                                            $isExpiringSoon = $cert['status'] == 'valid' && $diff->days <= 60 && $expiryDate > $today;
                                            $isExpired = $expiryDate < $today || $cert['status'] == 'expired';
                                            $cardClass = $isExpired ? 'expired' : ($isExpiringSoon ? 'expiring-soon' : '');
                                        ?>
                                            <div class="col-md-6 col-lg-4">
                                                <div class="card certificate-card <?= $cardClass ?>">
                                                    <div class="certificate-header d-flex align-items-center">
                                                        <?php
                                                        $iconClass = 'certificate';
                                                        switch ($cert['certification_type']) {
                                                            case 'HACCP':
                                                                $iconClass = 'shield-alt';
                                                                break;
                                                            case 'ISO22000':
                                                                $iconClass = 'check-circle';
                                                                break;
                                                            case 'GREEN_FOOD':
                                                                $iconClass = 'seedling';
                                                                break;
                                                        }
                                                        ?>
                                                        <i class="fas fa-<?= $iconClass ?> certificate-icon text-<?= getStatusClass($cert['status']) ?>"></i>
                                                        <div>
                                                            <h5 class="mb-0"><?= htmlspecialchars($cert['name']) ?></h5>
                                                            <small class="text-muted"><?= getCertificationType($cert['certification_type']) ?></small>
                                                        </div>
                                                        <span class="certificate-badge badge badge-<?= getStatusClass($cert['status']) ?>">
                                                            <?= getCertificationStatus($cert['status']) ?>
                                                        </span>
                                                    </div>
                                                    <div class="certificate-body">
                                                        <div class="cert-property">
                                                            <span class="cert-property-label">证书编号:</span>
                                                            <?= htmlspecialchars($cert['certificate_number']) ?>
                                                        </div>
                                                        <div class="cert-property">
                                                            <span class="cert-property-label">颁发机构:</span>
                                                            <?= htmlspecialchars($cert['issuing_authority']) ?>
                                                        </div>
                                                        <div class="cert-property">
                                                            <span class="cert-property-label">颁发日期:</span>
                                                            <?= date('Y-m-d', strtotime($cert['issue_date'])) ?>
                                                        </div>
                                                        <div class="cert-property">
                                                            <span class="cert-property-label">到期日期:</span>
                                                            <span class="expiry-date <?= $isExpiringSoon ? 'text-warning' : ($isExpired ? 'text-danger' : '') ?>">
                                                                <?= date('Y-m-d', strtotime($cert['expiry_date'])) ?>
                                                                <?php if ($cert['status'] == 'valid'): ?>
                                                                    <span class="days-left">
                                                                        <?php
                                                                        if ($expiryDate < $today) {
                                                                            echo '(已过期)';
                                                                        } elseif ($diff->days <= 60) {
                                                                            echo '(还剩' . $diff->days . '天)';
                                                                        }
                                                                        ?>
                                                                    </span>
                                                                <?php endif; ?>
                                                            </span>
                                                        </div>
                                                        <?php if ($cert['notes']): ?>
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">备注:</span>
                                                                <?= htmlspecialchars($cert['notes']) ?>
                                                            </div>
                                                        <?php endif; ?>
                                                        <?php if ($cert['file_path']): ?>
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">证书文件:</span>
                                                                <a href="../<?= $cert['file_path'] ?>" target="_blank" class="file-link">
                                                                    <i class="fas fa-file-pdf mr-1"></i>查看证书
                                                                </a>
                                                            </div>
                                                        <?php endif; ?>
                                                    </div>
                                                    <div class="certificate-footer d-flex justify-content-between">
                                                        <small class="text-muted">
                                                            创建者: <?= htmlspecialchars($cert['created_by_username'] ?? '未知') ?>
                                                        </small>
                                                        <div>
                                                            <a href="certification_management.php?action=edit&id=<?= $cert['id'] ?>" class="btn btn-sm btn-info">
                                                                <i class="fas fa-edit"></i>
                                                            </a>
                                                            <a href="certification_management.php?delete=<?= $cert['id'] ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此认证记录吗？')">
                                                                <i class="fas fa-trash"></i>
                                                            </a>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                <?php endif; ?>
                            </div>

                            <?php
                            // 处理按认证类型筛选的标签页
                            $types = ['haccp' => 'HACCP', 'iso22000' => 'ISO22000', 'green-food' => 'GREEN_FOOD'];
                            foreach ($types as $tabId => $certType):
                                $filteredCerts = array_filter($certifications, function ($cert) use ($certType) {
                                    return $cert['certification_type'] == $certType;
                                });
                            ?>
                                <div class="tab-pane fade" id="<?= $tabId ?>" role="tabpanel">
                                    <?php if (empty($filteredCerts)): ?>
                                        <div class="alert alert-info">
                                            <i class="fas fa-info-circle mr-2"></i>暂无<?= getCertificationType($certType) ?>记录
                                        </div>
                                    <?php else: ?>
                                        <div class="row">
                                            <?php
                                            foreach ($filteredCerts as $cert):
                                                $expiryDate = new DateTime($cert['expiry_date']);
                                                $diff = $today->diff($expiryDate);
                                                $isExpiringSoon = $cert['status'] == 'valid' && $diff->days <= 60 && $expiryDate > $today;
                                                $isExpired = $expiryDate < $today || $cert['status'] == 'expired';
                                                $cardClass = $isExpired ? 'expired' : ($isExpiringSoon ? 'expiring-soon' : '');
                                            ?>
                                                <div class="col-md-6 col-lg-4">
                                                    <div class="card certificate-card <?= $cardClass ?>">
                                                        <div class="certificate-header d-flex align-items-center">
                                                            <?php
                                                            $iconClass = 'certificate';
                                                            switch ($cert['certification_type']) {
                                                                case 'HACCP':
                                                                    $iconClass = 'shield-alt';
                                                                    break;
                                                                case 'ISO22000':
                                                                    $iconClass = 'check-circle';
                                                                    break;
                                                                case 'GREEN_FOOD':
                                                                    $iconClass = 'seedling';
                                                                    break;
                                                            }
                                                            ?>
                                                            <i class="fas fa-<?= $iconClass ?> certificate-icon text-<?= getStatusClass($cert['status']) ?>"></i>
                                                            <div>
                                                                <h5 class="mb-0"><?= htmlspecialchars($cert['name']) ?></h5>
                                                                <small class="text-muted"><?= getCertificationType($cert['certification_type']) ?></small>
                                                            </div>
                                                            <span class="certificate-badge badge badge-<?= getStatusClass($cert['status']) ?>">
                                                                <?= getCertificationStatus($cert['status']) ?>
                                                            </span>
                                                        </div>
                                                        <div class="certificate-body">
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">证书编号:</span>
                                                                <?= htmlspecialchars($cert['certificate_number']) ?>
                                                            </div>
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">颁发机构:</span>
                                                                <?= htmlspecialchars($cert['issuing_authority']) ?>
                                                            </div>
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">颁发日期:</span>
                                                                <?= date('Y-m-d', strtotime($cert['issue_date'])) ?>
                                                            </div>
                                                            <div class="cert-property">
                                                                <span class="cert-property-label">到期日期:</span>
                                                                <span class="expiry-date <?= $isExpiringSoon ? 'text-warning' : ($isExpired ? 'text-danger' : '') ?>">
                                                                    <?= date('Y-m-d', strtotime($cert['expiry_date'])) ?>
                                                                    <?php if ($cert['status'] == 'valid'): ?>
                                                                        <span class="days-left">
                                                                            <?php
                                                                            if ($expiryDate < $today) {
                                                                                echo '(已过期)';
                                                                            } elseif ($diff->days <= 60) {
                                                                                echo '(还剩' . $diff->days . '天)';
                                                                            }
                                                                            ?>
                                                                        </span>
                                                                    <?php endif; ?>
                                                                </span>
                                                            </div>
                                                            <?php if ($cert['notes']): ?>
                                                                <div class="cert-property">
                                                                    <span class="cert-property-label">备注:</span>
                                                                    <?= htmlspecialchars($cert['notes']) ?>
                                                                </div>
                                                            <?php endif; ?>
                                                            <?php if ($cert['file_path']): ?>
                                                                <div class="cert-property">
                                                                    <span class="cert-property-label">证书文件:</span>
                                                                    <a href="../<?= $cert['file_path'] ?>" target="_blank" class="file-link">
                                                                        <i class="fas fa-file-pdf mr-1"></i>查看证书
                                                                    </a>
                                                                </div>
                                                            <?php endif; ?>
                                                        </div>
                                                        <div class="certificate-footer d-flex justify-content-between">
                                                            <small class="text-muted">
                                                                创建者: <?= htmlspecialchars($cert['created_by_username'] ?? '未知') ?>
                                                            </small>
                                                            <div>
                                                                <a href="certification_management.php?action=edit&id=<?= $cert['id'] ?>" class="btn btn-sm btn-info">
                                                                    <i class="fas fa-edit"></i>
                                                                </a>
                                                                <a href="certification_management.php?delete=<?= $cert['id'] ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此认证记录吗？')">
                                                                    <i class="fas fa-trash"></i>
                                                                </a>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            <?php endforeach; ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- 添加认证模态框 -->
    <div class="modal fade" id="addCertModal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header bg-primary text-white">
                    <h5 class="modal-title">添加认证</h5>
                    <button type="button" class="close text-white" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form action="certification_management.php" method="post" enctype="multipart/form-data">
                    <div class="modal-body">
                        <input type="hidden" name="action" value="create">

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="name">认证名称<span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" id="name" name="name" required>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="certification_type">认证类型<span class="text-danger">*</span></label>
                                    <select class="form-control" id="certification_type" name="certification_type" required>
                                        <option value="">选择认证类型</option>
                                        <option value="HACCP">HACCP认证</option>
                                        <option value="ISO22000">ISO22000认证</option>
                                        <option value="GREEN_FOOD">绿色食品认证</option>
                                        <option value="OTHER">其他认证</option>
                                    </select>
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="certificate_number">证书编号<span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" id="certificate_number" name="certificate_number" required>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="issuing_authority">颁发机构<span class="text-danger">*</span></label>
                                    <input type="text" class="form-control" id="issuing_authority" name="issuing_authority" required>
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="issue_date">颁发日期<span class="text-danger">*</span></label>
                                    <input type="date" class="form-control" id="issue_date" name="issue_date" required value="<?= date('Y-m-d') ?>">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="expiry_date">到期日期<span class="text-danger">*</span></label>
                                    <input type="date" class="form-control" id="expiry_date" name="expiry_date" required value="<?= date('Y-m-d', strtotime('+3 years')) ?>">
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="status">认证状态<span class="text-danger">*</span></label>
                                    <select class="form-control" id="status" name="status" required>
                                        <option value="valid" selected>有效</option>
                                        <option value="pending">待审核</option>
                                        <option value="expired">已过期</option>
                                        <option value="revoked">已撤销</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="certificate_file">证书文件</label>
                                    <input type="file" class="form-control-file" id="certificate_file" name="certificate_file" accept=".pdf,.jpg,.jpeg,.png">
                                    <small class="form-text text-muted">支持的文件格式: PDF, JPG, JPEG, PNG</small>
                                </div>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="notes">备注</label>
                            <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                        <button type="submit" class="btn btn-primary">添加认证</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <?php
    // 处理编辑认证表单
    if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])):
        $certData = [];

        try {
            $stmt = $pdo->prepare("SELECT * FROM certifications WHERE id = ?");
            $stmt->execute([$_GET['id']]);
            $certData = $stmt->fetch();

            if (!$certData) {
                echo '<div class="alert alert-danger">未找到指定的认证记录</div>';
                exit;
            }
        } catch (PDOException $e) {
            echo '<div class="alert alert-danger">查询认证记录失败: ' . $e->getMessage() . '</div>';
            exit;
        }
    ?>
        <div class="modal fade show" id="editCertModal" tabindex="-1" style="display: block; padding-right: 17px; background: rgba(0,0,0,0.5);">
            <div class="modal-dialog modal-lg">
                <div class="modal-content">
                    <div class="modal-header bg-primary text-white">
                        <h5 class="modal-title">编辑认证</h5>
                        <a href="certification_management.php" class="close text-white">
                            <span aria-hidden="true">&times;</span>
                        </a>
                    </div>
                    <form action="certification_management.php" method="post" enctype="multipart/form-data">
                        <div class="modal-body">
                            <input type="hidden" name="action" value="update">
                            <input type="hidden" name="id" value="<?= $certData['id'] ?>">

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_name">认证名称<span class="text-danger">*</span></label>
                                        <input type="text" class="form-control" id="edit_name" name="name" required
                                            value="<?= htmlspecialchars($certData['name']) ?>">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_certification_type">认证类型<span class="text-danger">*</span></label>
                                        <select class="form-control" id="edit_certification_type" name="certification_type" required>
                                            <option value="">选择认证类型</option>
                                            <option value="HACCP" <?= $certData['certification_type'] == 'HACCP' ? 'selected' : '' ?>>HACCP认证</option>
                                            <option value="ISO22000" <?= $certData['certification_type'] == 'ISO22000' ? 'selected' : '' ?>>ISO22000认证</option>
                                            <option value="GREEN_FOOD" <?= $certData['certification_type'] == 'GREEN_FOOD' ? 'selected' : '' ?>>绿色食品认证</option>
                                            <option value="OTHER" <?= $certData['certification_type'] == 'OTHER' ? 'selected' : '' ?>>其他认证</option>
                                        </select>
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_certificate_number">证书编号<span class="text-danger">*</span></label>
                                        <input type="text" class="form-control" id="edit_certificate_number" name="certificate_number" required
                                            value="<?= htmlspecialchars($certData['certificate_number']) ?>">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_issuing_authority">颁发机构<span class="text-danger">*</span></label>
                                        <input type="text" class="form-control" id="edit_issuing_authority" name="issuing_authority" required
                                            value="<?= htmlspecialchars($certData['issuing_authority']) ?>">
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_issue_date">颁发日期<span class="text-danger">*</span></label>
                                        <input type="date" class="form-control" id="edit_issue_date" name="issue_date" required
                                            value="<?= $certData['issue_date'] ?>">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_expiry_date">到期日期<span class="text-danger">*</span></label>
                                        <input type="date" class="form-control" id="edit_expiry_date" name="expiry_date" required
                                            value="<?= $certData['expiry_date'] ?>">
                                    </div>
                                </div>
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_status">认证状态<span class="text-danger">*</span></label>
                                        <select class="form-control" id="edit_status" name="status" required>
                                            <option value="valid" <?= $certData['status'] == 'valid' ? 'selected' : '' ?>>有效</option>
                                            <option value="pending" <?= $certData['status'] == 'pending' ? 'selected' : '' ?>>待审核</option>
                                            <option value="expired" <?= $certData['status'] == 'expired' ? 'selected' : '' ?>>已过期</option>
                                            <option value="revoked" <?= $certData['status'] == 'revoked' ? 'selected' : '' ?>>已撤销</option>
                                        </select>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label for="edit_certificate_file">证书文件</label>
                                        <input type="file" class="form-control-file" id="edit_certificate_file" name="certificate_file"
                                            accept=".pdf,.jpg,.jpeg,.png">
                                        <?php if ($certData['file_path']): ?>
                                            <div class="mt-2">
                                                <span class="text-info">已上传文件: </span>
                                                <a href="../<?= $certData['file_path'] ?>" target="_blank" class="file-link">
                                                    <i class="fas fa-file mr-1"></i>查看文件
                                                </a>
                                                <div class="form-check mt-2">
                                                    <input type="checkbox" class="form-check-input" id="keep_file" name="keep_file" value="1" checked>
                                                    <label class="form-check-label" for="keep_file">保留现有文件</label>
                                                </div>
                                            </div>
                                        <?php endif; ?>
                                        <small class="form-text text-muted">支持的文件格式: PDF, JPG, JPEG, PNG</small>
                                    </div>
                                </div>
                            </div>

                            <div class="form-group">
                                <label for="edit_notes">备注</label>
                                <textarea class="form-control" id="edit_notes" name="notes" rows="3"><?= htmlspecialchars($certData['notes']) ?></textarea>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <a href="certification_management.php" class="btn btn-secondary">取消</a>
                            <button type="submit" class="btn btn-primary">保存修改</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <script src="https://cdn.bootcdn.net/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/js/bootstrap.bundle.min.js"></script>
    <script>
        // 初始化标签页
        $(document).ready(function() {
            // 启用标签页
            $('#certificationTabs a').on('click', function(e) {
                e.preventDefault();
                $(this).tab('show');
            });

            // 文件上传预览
            $('#certificate_file').on('change', function() {
                if (this.files && this.files[0]) {
                    $('#keep_file').prop('checked', false);
                }
            });

            // 日期字段验证
            $('#issue_date, #expiry_date').on('change', function() {
                const issueDate = new Date($('#issue_date').val());
                const expiryDate = new Date($('#expiry_date').val());

                if (expiryDate <= issueDate) {
                    alert('到期日期必须晚于颁发日期');
                    $(this).val('');
                }
            });
        });

        // 确认删除
        function confirmDelete(id) {
            if (confirm('确定要删除此认证记录吗？这个操作不可恢复。')) {
                window.location.href = 'certification_management.php?delete=' + id;
            }
        }
    </script>
</body>

</html>