<?php
// food_safety_tracking.php - 食品安全溯源功能
// 从原料到成品的批次追踪

require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理搜索请求
$searchType = $_GET['search_type'] ?? 'product';
$searchTerm = $_GET['search_term'] ?? '';
$traceType = $_GET['trace_type'] ?? 'backward'; // backward: 从成品到原料, forward: 从原料到成品

// 追踪结果数组
$traceResults = [];
$product = null;
$batchInfo = null;
$supplierInfo = null;
$qualityTests = [];
$materialInfo = [];
$relatedBatches = [];

// 获取所有产品列表用于搜索下拉框
$products = [];
try {
    $stmt = $pdo->query("
        SELECT id, name, type 
        FROM products 
        ORDER BY type, name
    ");
    $products = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "查询产品信息失败: " . $e->getMessage();
}

// 在页面加载时获取所有批次号
$batchNumbers = [];
try {
    $stmt = $pdo->query("
        SELECT batch_number 
        FROM production_batches 
        GROUP BY batch_number
        ORDER BY MAX(created_at) DESC 
        LIMIT 100
    ");
    $batchNumbers = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    $error = "查询批次信息失败: " . $e->getMessage();
}

// 当有搜索条件时执行查询
if ($searchTerm) {
    try {
        // 1. 根据搜索类型获取初始数据
        if ($searchType == 'batch') {
            // 通过批次号搜索
            $stmt = $pdo->prepare("
                SELECT pb.*, p.name as product_name, p.type as product_type 
                FROM production_batches pb
                JOIN products p ON pb.product_id = p.id
                WHERE pb.batch_number = :batch_number
                LIMIT 1
            ");
            $stmt->execute([':batch_number' => $searchTerm]);
            $batchInfo = $stmt->fetch();

            if ($batchInfo) {
                $product = [
                    'id' => $batchInfo['product_id'],
                    'name' => $batchInfo['product_name'],
                    'type' => $batchInfo['product_type']
                ];
            }
        } elseif ($searchType == 'product') {
            // 通过产品ID搜索，查找最近的批次
            $stmt = $pdo->prepare("
                SELECT p.id, p.name, p.type, p.description
                FROM products p 
                WHERE p.id = :product_id
                LIMIT 1
            ");
            $stmt->execute([':product_id' => $searchTerm]);
            $product = $stmt->fetch();

            if ($product) {
                // 查找该产品最近的批次
                $stmt = $pdo->prepare("
                    SELECT * FROM production_batches 
                    WHERE product_id = :product_id 
                    ORDER BY id DESC 
                    LIMIT 1
                ");
                $stmt->execute([':product_id' => $product['id']]);
                $batchInfo = $stmt->fetch();
            }
        } elseif ($searchType == 'material') {
            // 通过原料批次号搜索
            $stmt = $pdo->prepare("
                SELECT mr.*, p.name as product_name, p.type as product_type 
                FROM material_receiving mr
                JOIN products p ON mr.product_id = p.id
                WHERE mr.batch_number = :batch_number
                LIMIT 1
            ");
            $stmt->execute([':batch_number' => $searchTerm]);
            $materialInfo = $stmt->fetch();

            if ($materialInfo) {
                $product = [
                    'id' => $materialInfo['product_id'],
                    'name' => $materialInfo['product_name'],
                    'type' => $materialInfo['product_type']
                ];

                // 如果是追踪到成品，需要查找使用该原料的生产批次
                if ($traceType == 'forward') {
                    // 实际生产中需要维护原料使用记录表，这里简化处理
                    $stmt = $pdo->prepare("
                        SELECT * FROM production_batches 
                        WHERE start_time >= :material_date
                        ORDER BY start_time ASC
                        LIMIT 10
                    ");
                    $stmt->execute([':material_date' => $materialInfo['received_date']]);
                    $relatedBatches = $stmt->fetchAll();
                }
            }
        }

        // 2. 根据批次信息执行溯源查询
        if ($batchInfo && $traceType == 'backward') {
            // 2.1 查询批次对应的质检记录
            $stmt = $pdo->prepare("
                SELECT qc.*, u.username as tester_name
                FROM qc_finished_goods_tests qc
                LEFT JOIN users u ON qc.tester_id = u.id
                WHERE qc.production_batch_id = :batch_id
                ORDER BY qc.test_date DESC
            ");
            $stmt->execute([':batch_id' => $batchInfo['id']]);
            $qualityTests = $stmt->fetchAll();

            // 2.2 查询批次使用的原料 (简化版，实际生产中需要建立原料使用记录表)
            // 这里假设原料是在批次开始前一周内入库的相关原料
            if ($batchInfo['start_time']) {
                $oneWeekBefore = date('Y-m-d H:i:s', strtotime($batchInfo['start_time'] . ' -1 week'));

                $stmt = $pdo->prepare("
                    SELECT mr.*, p.name as product_name, p.type as product_type,
                           s.name as supplier_name, s.contact_person, s.phone
                    FROM material_receiving mr
                    JOIN products p ON mr.product_id = p.id
                    LEFT JOIN purchase_order_items poi ON mr.purchase_order_item_id = poi.id
                    LEFT JOIN purchase_orders po ON poi.purchase_order_id = po.id
                    LEFT JOIN suppliers s ON po.supplier_id = s.id
                    WHERE p.type = 'raw' AND mr.received_date BETWEEN :start_date AND :end_date
                    ORDER BY mr.received_date DESC
                ");
                $stmt->execute([
                    ':start_date' => $oneWeekBefore,
                    ':end_date' => $batchInfo['start_time']
                ]);
                $materialInfo = $stmt->fetchAll();
            }
        } elseif ($materialInfo && $traceType == 'forward') {
            // 原料向前追踪，查询该原料相关的采购信息
            if ($materialInfo['purchase_order_item_id']) {
                $stmt = $pdo->prepare("
                    SELECT poi.*, po.order_number, po.order_date, 
                           s.name as supplier_name, s.contact_person, s.phone
                    FROM purchase_order_items poi
                    JOIN purchase_orders po ON poi.purchase_order_id = po.id
                    JOIN suppliers s ON po.supplier_id = s.id
                    WHERE poi.id = :poi_id
                ");
                $stmt->execute([':poi_id' => $materialInfo['purchase_order_item_id']]);
                $supplierInfo = $stmt->fetch();
            }

            // 获取质检信息
            if ($materialInfo['inspector_id']) {
                $stmt = $pdo->prepare("
                    SELECT u.username FROM users u WHERE u.id = :inspector_id
                ");
                $stmt->execute([':inspector_id' => $materialInfo['inspector_id']]);
                $inspector = $stmt->fetchColumn();
                $materialInfo['inspector_name'] = $inspector;
            }
        }
    } catch (PDOException $e) {
        $error = "执行溯源查询失败: " . $e->getMessage();
    }
}

// 获取产品类型中文名称
function getProductTypeName($type)
{
    $types = [
        'raw' => '原料',
        'semi-finished' => '半成品',
        'finished' => '成品'
    ];
    return $types[$type] ?? $type;
}

// 获取批次状态中文名称
function getBatchStatusName($status)
{
    $statusMap = [
        'planned' => '计划中',
        'in_progress' => '生产中',
        'completed' => '已完成',
        'quality_check' => '质检中',
        'stocked' => '已入库',
        'cancelled' => '已取消'
    ];
    return $statusMap[$status] ?? $status;
}

// 获取质检结果中文名称
function getQualityResultName($result)
{
    $resultMap = [
        'passed' => '合格',
        'failed' => '不合格',
        'pending' => '待检验'
    ];
    return $resultMap[$result] ?? $result;
}

?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>食品安全溯源 - <?= title ?></title>
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    <style>
        .timeline {
            position: relative;
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px 0;
        }

        .timeline::after {
            content: '';
            position: absolute;
            width: 6px;
            background-color: #3498db;
            top: 0;
            bottom: 0;
            left: 50%;
            margin-left: -3px;
            border-radius: 3px;
        }

        .timeline-item {
            padding: 10px 40px;
            position: relative;
            width: 50%;
            box-sizing: border-box;
        }

        .timeline-item::after {
            content: '';
            position: absolute;
            width: 20px;
            height: 20px;
            background-color: white;
            border: 4px solid #3498db;
            border-radius: 50%;
            top: 15px;
            right: -10px;
            z-index: 1;
        }

        .left {
            left: 0;
        }

        .right {
            left: 50%;
        }

        .right::after {
            left: -10px;
        }

        .timeline-content {
            padding: 15px;
            background-color: white;
            border-radius: 6px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        .timeline-content h4 {
            margin-top: 0;
            color: #3498db;
        }

        .trace-direction {
            text-align: center;
            margin: 20px 0;
        }

        .trace-direction label {
            margin: 0 10px;
            cursor: pointer;
        }

        .trace-item {
            margin-bottom: 15px;
            border-left: 4px solid #3498db;
            padding: 10px 15px;
            background: #f8f9fa;
        }

        .trace-header {
            font-weight: bold;
            color: #2c3e50;
            margin-bottom: 5px;
        }

        .trace-detail {
            margin: 5px 0;
            color: #7f8c8d;
        }

        .source-info {
            margin-top: 10px;
            padding: 10px;
            background: #e8f4fd;
            border-radius: 4px;
        }

        .search-card {
            margin-bottom: 20px;
            background: #f8f9fa;
            border-radius: 8px;
            padding: 20px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.05);
        }
    </style>
</head>

<body>
    <div class="container-fluid mt-4">
        <div class="row">
            <div class="col-md-12 mb-4">
                <div class="card">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0"><i class="fas fa-history mr-2"></i>食品安全溯源</h5>
                    </div>
                    <div class="card-body">
                        <div class="search-card">
                            <form method="get" class="row">
                                <div class="col-md-3 form-group">
                                    <label for="search_type">搜索类型</label>
                                    <select name="search_type" id="search_type" class="form-control" onchange="updateSearchOptions()">
                                        <option value="batch" <?= $searchType == 'batch' ? 'selected' : '' ?>>按生产批次号</option>
                                        <option value="product" <?= $searchType == 'product' ? 'selected' : '' ?>>按产品</option>
                                        <option value="material" <?= $searchType == 'material' ? 'selected' : '' ?>>按原料批次号</option>
                                    </select>
                                </div>

                                <div class="col-md-4 form-group" id="productSearchGroup" style="<?= $searchType == 'product' ? '' : 'display:none' ?>">
                                    <label for="search_term">选择产品</label>
                                    <select name="search_term" class="form-control">
                                        <option value="">选择产品...</option>
                                        <?php foreach ($products as $p): ?>
                                            <option value="<?= $p['id'] ?>" <?= ($searchType == 'product' && $searchTerm == $p['id']) ? 'selected' : '' ?>>
                                                <?= $p['name'] ?> (<?= getProductTypeName($p['type']) ?>)
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>

                                <div class="col-md-4 form-group" id="batchSearchGroup" style="<?= $searchType != 'product' ? '' : 'display:none' ?>">
                                    <label for="search_term">选择批次号</label>
                                    <select name="search_term" class="form-control">
                                        <option value="">选择批次号...</option>
                                        <?php foreach ($batchNumbers as $batch): ?>
                                            <option value="<?= $batch ?>" <?= ($searchTerm == $batch) ? 'selected' : '' ?>>
                                                <?= $batch ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>

                                <div class="col-md-3 form-group">
                                    <label for="trace_type">追溯方向</label>
                                    <select name="trace_type" class="form-control">
                                        <option value="backward" <?= $traceType == 'backward' ? 'selected' : '' ?>>成品溯源到原料(回溯)</option>
                                        <option value="forward" <?= $traceType == 'forward' ? 'selected' : '' ?>>原料追踪到成品(追踪)</option>
                                    </select>
                                </div>

                                <div class="col-md-2 form-group">
                                    <label>&nbsp;</label>
                                    <button type="submit" class="btn btn-primary btn-block">
                                        <i class="fas fa-search mr-1"></i>开始溯源
                                    </button>
                                </div>
                            </form>
                        </div>

                        <?php if (isset($error)): ?>
                            <div class="alert alert-danger"><?= $error ?></div>
                        <?php endif; ?>

                        <?php if ($product && $traceType == 'backward' && $batchInfo): ?>
                            <!-- 产品及批次信息 -->
                            <div class="card mb-4">
                                <div class="card-header bg-info text-white">
                                    <h5 class="mb-0">产品批次基本信息</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <h5><?= $product['name'] ?> (<?= getProductTypeName($product['type']) ?>)</h5>
                                            <p class="text-muted">批次号: <?= $batchInfo['batch_number'] ?></p>
                                            <p>计划数量: <?= $batchInfo['quantity_planned'] ?> | 实际产量: <?= $batchInfo['quantity_produced'] ?? '未记录' ?></p>
                                            <p>批次状态: <span class="badge badge-<?= $batchInfo['status'] == 'completed' ? 'success' : 'info' ?>"><?= getBatchStatusName($batchInfo['status']) ?></span></p>
                                        </div>
                                        <div class="col-md-6">
                                            <p>开始时间: <?= $batchInfo['start_time'] ?? '未记录' ?></p>
                                            <p>结束时间: <?= $batchInfo['end_time'] ?? '未记录' ?></p>
                                            <p>生产成本: ¥<?= $batchInfo['actual_cost'] ?? $batchInfo['estimated_cost'] ?? '未记录' ?></p>
                                            <?php if (!empty($batchInfo['notes'])): ?>
                                                <p>备注: <?= $batchInfo['notes'] ?></p>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- 质检信息 -->
                            <?php if (!empty($qualityTests)): ?>
                                <div class="card mb-4">
                                    <div class="card-header bg-success text-white">
                                        <h5 class="mb-0">质量检验记录</h5>
                                    </div>
                                    <div class="card-body">
                                        <div class="table-responsive">
                                            <table class="table table-bordered table-sm">
                                                <thead class="thead-light">
                                                    <tr>
                                                        <th>检验项目</th>
                                                        <th>检验标准</th>
                                                        <th>检验结果</th>
                                                        <th>检验状态</th>
                                                        <th>检验时间</th>
                                                        <th>检验员</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php foreach ($qualityTests as $test): ?>
                                                        <tr>
                                                            <td><?= $test['test_name'] ?></td>
                                                            <td><?= $test['test_standard'] ?></td>
                                                            <td><?= $test['test_result_value'] ?></td>
                                                            <td>
                                                                <span class="badge badge-<?= $test['result'] == 'passed' ? 'success' : 'danger' ?>">
                                                                    <?= $test['result'] == 'passed' ? '合格' : '不合格' ?>
                                                                </span>
                                                            </td>
                                                            <td><?= $test['test_date'] ?></td>
                                                            <td><?= $test['tester_name'] ?? '未记录' ?></td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    </div>
                                </div>
                            <?php endif; ?>

                            <!-- 原料溯源 -->
                            <?php if (!empty($materialInfo)): ?>
                                <div class="card mb-4">
                                    <div class="card-header bg-warning text-dark">
                                        <h5 class="mb-0">原材料溯源信息</h5>
                                    </div>
                                    <div class="card-body">
                                        <div class="timeline">
                                            <?php
                                            $position = 'left';
                                            foreach ($materialInfo as $i => $material):
                                                $position = $i % 2 == 0 ? 'left' : 'right';
                                            ?>
                                                <div class="timeline-item <?= $position ?>">
                                                    <div class="timeline-content">
                                                        <h4><?= $material['product_name'] ?></h4>
                                                        <p><strong>批次号:</strong> <?= $material['batch_number'] ?></p>
                                                        <p><strong>接收日期:</strong> <?= $material['received_date'] ?></p>
                                                        <p><strong>接收数量:</strong> <?= $material['received_quantity'] ?></p>
                                                        <p><strong>质检结果:</strong>
                                                            <span class="badge badge-<?= $material['quality_check_result'] == 'passed' ? 'success' : ($material['quality_check_result'] == 'pending' ? 'warning' : 'danger') ?>">
                                                                <?= getQualityResultName($material['quality_check_result']) ?>
                                                            </span>
                                                        </p>
                                                        <?php if (!empty($material['supplier_name'])): ?>
                                                            <div class="source-info">
                                                                <p><strong>供应商:</strong> <?= $material['supplier_name'] ?></p>
                                                                <p><strong>联系人:</strong> <?= $material['contact_person'] ?> (<?= $material['phone'] ?>)</p>
                                                            </div>
                                                        <?php endif; ?>
                                                    </div>
                                                </div>
                                            <?php endforeach; ?>
                                        </div>
                                    </div>
                                </div>
                            <?php else: ?>
                                <div class="alert alert-info">未找到与该批次相关的原材料记录</div>
                            <?php endif; ?>

                        <?php elseif ($product && $traceType == 'forward' && $materialInfo): ?>
                            <!-- 原料信息 -->
                            <div class="card mb-4">
                                <div class="card-header bg-info text-white">
                                    <h5 class="mb-0">原料基本信息</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <h5><?= $product['name'] ?> (<?= getProductTypeName($product['type']) ?>)</h5>
                                            <p class="text-muted">批次号: <?= $materialInfo['batch_number'] ?></p>
                                            <p>接收数量: <?= $materialInfo['received_quantity'] ?></p>
                                            <p>接收日期: <?= $materialInfo['received_date'] ?></p>
                                            <p>质检结果:
                                                <span class="badge badge-<?= $materialInfo['quality_check_result'] == 'passed' ? 'success' : ($materialInfo['quality_check_result'] == 'pending' ? 'warning' : 'danger') ?>">
                                                    <?= getQualityResultName($materialInfo['quality_check_result']) ?>
                                                </span>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <?php if (!empty($supplierInfo)): ?>
                                                <div class="source-info">
                                                    <h6>供应商信息</h6>
                                                    <p><strong>供应商:</strong> <?= $supplierInfo['supplier_name'] ?></p>
                                                    <p><strong>订单号:</strong> <?= $supplierInfo['order_number'] ?></p>
                                                    <p><strong>订单日期:</strong> <?= $supplierInfo['order_date'] ?></p>
                                                    <p><strong>联系人:</strong> <?= $supplierInfo['contact_person'] ?> (<?= $supplierInfo['phone'] ?>)</p>
                                                </div>
                                            <?php endif; ?>
                                            <?php if (!empty($materialInfo['inspector_name'])): ?>
                                                <p><strong>质检员:</strong> <?= $materialInfo['inspector_name'] ?></p>
                                            <?php endif; ?>
                                            <?php if (!empty($materialInfo['inspection_notes'])): ?>
                                                <p><strong>质检备注:</strong> <?= $materialInfo['inspection_notes'] ?></p>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <!-- 相关生产批次 -->
                            <?php if (!empty($relatedBatches)): ?>
                                <div class="card mb-4">
                                    <div class="card-header bg-success text-white">
                                        <h5 class="mb-0">相关生产批次</h5>
                                    </div>
                                    <div class="card-body">
                                        <p class="alert alert-info">
                                            <i class="fas fa-info-circle mr-2"></i>以下为原料入库后创建的生产批次，可能使用了此批次原料
                                        </p>
                                        <div class="table-responsive">
                                            <table class="table table-bordered table-sm">
                                                <thead class="thead-light">
                                                    <tr>
                                                        <th>批次号</th>
                                                        <th>产品</th>
                                                        <th>计划数量</th>
                                                        <th>实际产量</th>
                                                        <th>开始时间</th>
                                                        <th>结束时间</th>
                                                        <th>状态</th>
                                                        <th>操作</th>
                                                    </tr>
                                                </thead>
                                                <tbody>
                                                    <?php foreach ($relatedBatches as $batch):
                                                        // 获取产品名称
                                                        $stmt = $pdo->prepare("SELECT name FROM products WHERE id = ?");
                                                        $stmt->execute([$batch['product_id']]);
                                                        $productName = $stmt->fetchColumn();
                                                    ?>
                                                        <tr>
                                                            <td><?= $batch['batch_number'] ?></td>
                                                            <td><?= $productName ?></td>
                                                            <td><?= $batch['quantity_planned'] ?></td>
                                                            <td><?= $batch['quantity_produced'] ?? '-' ?></td>
                                                            <td><?= $batch['start_time'] ?? '-' ?></td>
                                                            <td><?= $batch['end_time'] ?? '-' ?></td>
                                                            <td>
                                                                <span class="badge badge-<?= $batch['status'] == 'completed' ? 'success' : ($batch['status'] == 'in_progress' ? 'primary' : 'secondary') ?>">
                                                                    <?= getBatchStatusName($batch['status']) ?>
                                                                </span>
                                                            </td>
                                                            <td>
                                                                <a href="?search_type=batch&search_term=<?= $batch['batch_number'] ?>&trace_type=backward" class="btn btn-sm btn-info">
                                                                    查看溯源
                                                                </a>
                                                            </td>
                                                        </tr>
                                                    <?php endforeach; ?>
                                                </tbody>
                                            </table>
                                        </div>
                                    </div>
                                </div>
                            <?php else: ?>
                                <div class="alert alert-info">未找到与该原料相关的生产批次</div>
                            <?php endif; ?>

                        <?php elseif ($product && !$batchInfo): ?>
                            <div class="alert alert-info">
                                <i class="fas fa-info-circle mr-2"></i>未找到该产品的批次记录，无法进行溯源
                            </div>
                        <?php elseif ($searchTerm): ?>
                            <div class="alert alert-warning">
                                <i class="fas fa-exclamation-triangle mr-2"></i>未找到相关记录，请检查输入信息是否正确
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/js/bootstrap.bundle.min.js"></script>
    <script>
        function updateSearchOptions() {
            const searchType = document.getElementById('search_type').value;

            if (searchType === 'product') {
                document.getElementById('productSearchGroup').style.display = '';
                document.getElementById('batchSearchGroup').style.display = 'none';
            } else {
                document.getElementById('productSearchGroup').style.display = 'none';
                document.getElementById('batchSearchGroup').style.display = '';
            }
        }
    </script>
</body>

</html>