<?php
session_start();
require_once '../config.php';

// 定义订单状态转换函数
function get_order_status_text($status)
{
    $order_statuses = [
        'draft' => '草稿',
        'confirmed' => '已确认',
        'processing' => '处理中',
        'partially_shipped' => '部分发货',
        'shipped' => '已发货',
        'delivered' => '已送达',
        'cancelled' => '已取消'
    ];

    return isset($order_statuses[$status]) ? $order_statuses[$status] : $status;
}

// 检查用户是否登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$order = null;
$order_items = [];
$customer = null;

try {
    // 检查是否提供了订单ID
    if (!isset($_GET['id']) || empty($_GET['id'])) {
        throw new Exception('未提供订单ID');
    }

    $order_id = intval($_GET['id']);

    // 检查必要的表是否存在
    $required_tables = [
        'sales_orders' => ['id', 'order_number', 'customer_id', 'sales_channel_id', 'order_date', 'total_amount', 'status', 'notes'],
        'sales_order_items' => ['id', 'sales_order_id', 'product_id', 'quantity', 'unit_price', 'item_total_amount'],
        'customers' => ['id', 'name', 'contact_person', 'phone', 'address'],
        'products' => ['id', 'name', 'unit']
    ];

    foreach ($required_tables as $table => $columns) {
        // 检查表是否存在
        $table_exists = $pdo->query("SHOW TABLES LIKE '$table'")->rowCount() > 0;
        if (!$table_exists) {
            throw new Exception("表 $table 不存在");
        }

        // 检查列是否存在
        $table_columns = $pdo->query("SHOW COLUMNS FROM $table")->fetchAll(PDO::FETCH_COLUMN);
        $missing_columns = array_diff($columns, $table_columns);
        if (!empty($missing_columns)) {
            throw new Exception("表 $table 缺少以下列: " . implode(', ', $missing_columns));
        }
    }

    // 查询订单基本信息
    $stmt = $pdo->prepare("
        SELECT 
            so.*,
            c.name as customer_name,
            c.contact_person,
            c.phone,
            c.address,
            sc.name as channel_name
        FROM sales_orders so
        LEFT JOIN customers c ON so.customer_id = c.id
        LEFT JOIN sales_channels sc ON so.sales_channel_id = sc.id
        WHERE so.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$order) {
        throw new Exception('未找到指定订单');
    }

    // 查询订单项目
    $stmt = $pdo->prepare("
        SELECT 
            soi.*,
            p.name as product_name,
            p.specification,
            p.type,
            p.unit
        FROM sales_order_items soi
        LEFT JOIN products p ON soi.product_id = p.id
        WHERE soi.sales_order_id = ?
    ");
    $stmt->execute([$order_id]);
    $order_items = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (Exception $e) {
    $error = $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>订单详情 - FruitEase</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .container {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .order-details {
            margin-bottom: 30px;
        }

        .order-details h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        .data-table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 25px;
            background: white;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            border-radius: 8px;
            overflow: hidden;
        }

        .data-table th,
        .data-table td {
            padding: 12px 15px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        .data-table th {
            background-color: #f8f9fa;
            color: #333;
            font-weight: bold;
        }

        .text-right {
            text-align: right;
        }

        .button-group {
            display: flex;
            gap: 10px;
            margin-top: 20px;
        }

        .button {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            text-decoration: none;
            display: inline-block;
            transition: background 0.3s;
        }

        .button:hover {
            background: #2980b9;
        }

        .error-message {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>订单详情</h1>
        <?php if ($error): ?>
            <div class="error-message"><?php echo htmlspecialchars($error); ?></div>
        <?php else: ?>
            <div class="order-details">
                <h2>基本信息</h2>
                <table class="data-table">
                    <tr>
                        <th>订单编号</th>
                        <td><?php echo htmlspecialchars($order['order_number']); ?></td>
                        <th>订单日期</th>
                        <td><?php echo htmlspecialchars($order['order_date']); ?></td>
                    </tr>
                    <tr>
                        <th>客户名称</th>
                        <td><?php echo htmlspecialchars($order['customer_name']); ?></td>
                        <th>销售渠道</th>
                        <td><?php echo htmlspecialchars($order['channel_name']); ?></td>
                    </tr>
                    <tr>
                        <th>联系人</th>
                        <td><?php echo htmlspecialchars($order['contact_person']); ?></td>
                        <th>联系电话</th>
                        <td><?php echo htmlspecialchars($order['phone']); ?></td>
                    </tr>
                    <tr>
                        <th>地址</th>
                        <td colspan="3"><?php echo htmlspecialchars($order['address']); ?></td>
                    </tr>
                    <tr>
                        <th>订单状态</th>
                        <td><?php echo get_order_status_text($order['status']); ?></td>
                        <th>总金额</th>
                        <td>￥<?php echo number_format($order['total_amount'], 2); ?></td>
                    </tr>
                    <?php if (!empty($order['notes'])): ?>
                        <tr>
                            <th>备注</th>
                            <td colspan="3"><?php echo nl2br(htmlspecialchars($order['notes'])); ?></td>
                        </tr>
                    <?php endif; ?>
                </table>

                <h2>订单项目</h2>
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>规格</th>
                            <th>类型</th>
                            <th>数量</th>
                            <th>单位</th>
                            <th>单价</th>
                            <th>小计</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($order_items as $item): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                <td><?php echo htmlspecialchars($item['specification'] ?? '-'); ?></td>
                                <td><?php
                                    $type_map = [
                                        'raw' => '原料',
                                        'semi-finished' => '半成品',
                                        'finished' => '成品'
                                    ];
                                    echo htmlspecialchars($type_map[$item['type']] ?? $item['type']);
                                    ?></td>
                                <td><?php echo htmlspecialchars($item['quantity']); ?></td>
                                <td><?php echo htmlspecialchars($item['unit']); ?></td>
                                <td>￥<?php echo number_format($item['unit_price'], 2); ?></td>
                                <td>￥<?php echo number_format($item['item_total_amount'], 2); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                    <tfoot>
                        <tr>
                            <td colspan="5" class="text-right"><strong>总计</strong></td>
                            <td><strong>￥<?php echo number_format($order['total_amount'], 2); ?></strong></td>
                        </tr>
                    </tfoot>
                </table>
            </div>

            <div class="button-group">
                <a href="order_list.php" class="button">返回列表</a>
                <?php if ($order['status'] == 'draft'): ?>
                    <a href="order_edit.php?id=<?php echo $order_id; ?>" class="button">编辑订单</a>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</body>

</html>