<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// CSRF验证
if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
    $_SESSION['error'] = "安全验证失败，请重试";
    header("Location: material_receiving.php");
    exit;
}

// 验证必填字段
$required_fields = ['order_item_id', 'received_date', 'received_quantity', 'lot_number', 'quality_check_result', 'storage_location_id'];
foreach ($required_fields as $field) {
    if (!isset($_POST[$field]) || trim($_POST[$field]) === '') {
        $_SESSION['error'] = "{$field}是必填项";
        header("Location: " . ($_POST['order_id'] ? "material_receiving.php?order_id=" . $_POST['order_id'] : "material_receiving.php"));
        exit;
    }
}

// 获取表单数据
$order_item_id = (int)$_POST['order_item_id'];
$received_date = $_POST['received_date'];
$received_quantity = (float)$_POST['received_quantity'];
$batch_number = trim($_POST['lot_number']);
$quality_check_result = $_POST['quality_check_result'];
$inspector_id = !empty($_POST['inspector_id']) ? (int)$_POST['inspector_id'] : null;
$storage_location_id = (int)$_POST['storage_location_id'];
$inspection_notes = trim($_POST['inspection_notes'] ?? '');

try {
    $pdo->beginTransaction();

    // 检查订单项是否存在并获取相关信息
    $stmt = $pdo->prepare("
        SELECT 
            poi.id, 
            poi.purchase_order_id,
            poi.product_id,
            poi.quantity,
            poi.received_quantity,
            po.status,
            p.name AS product_name
        FROM purchase_order_items poi
        JOIN purchase_orders po ON poi.purchase_order_id = po.id
        JOIN products p ON poi.product_id = p.id
        WHERE poi.id = ?
    ");
    $stmt->execute([$order_item_id]);
    $orderItem = $stmt->fetch();

    if (!$orderItem) {
        throw new Exception("订单项不存在");
    }

    // 检查入库数量是否合法
    $remaining_quantity = $orderItem['quantity'] - $orderItem['received_quantity'];
    if ($received_quantity <= 0) {
        throw new Exception("入库数量必须大于0");
    }
    if ($received_quantity > $remaining_quantity) {
        throw new Exception("入库数量不能超过剩余数量 {$remaining_quantity}");
    }

    // 创建入库记录
    $stmt = $pdo->prepare("
        INSERT INTO material_receiving (
            purchase_order_item_id, 
            product_id, 
            received_date, 
            received_quantity, 
            batch_number, 
            quality_check_result, 
            inspector_id, 
            inspection_notes, 
            storage_location_id
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt->execute([
        $order_item_id,
        $orderItem['product_id'],
        $received_date,
        $received_quantity,
        $batch_number,
        $quality_check_result,
        $inspector_id,
        $inspection_notes,
        $storage_location_id
    ]);
    $receiving_id = $pdo->lastInsertId();

    // 更新订单项的已接收数量
    $new_received_quantity = $orderItem['received_quantity'] + $received_quantity;
    $stmt = $pdo->prepare("
        UPDATE purchase_order_items 
        SET received_quantity = ? 
        WHERE id = ?
    ");
    $stmt->execute([$new_received_quantity, $order_item_id]);

    // 检查订单状态是否需要更新
    $stmt = $pdo->prepare("
        SELECT 
            SUM(quantity) AS total_quantity,
            SUM(received_quantity) AS total_received
        FROM purchase_order_items 
        WHERE purchase_order_id = ?
    ");
    $stmt->execute([$orderItem['purchase_order_id']]);
    $totals = $stmt->fetch();

    $new_status = $orderItem['status'];
    if ($totals['total_received'] >= $totals['total_quantity']) {
        $new_status = 'received';
    } else if ($totals['total_received'] > 0) {
        $new_status = 'partially_received';
    }

    if ($new_status !== $orderItem['status']) {
        $stmt = $pdo->prepare("
            UPDATE purchase_orders 
            SET status = ? 
            WHERE id = ?
        ");
        $stmt->execute([$new_status, $orderItem['purchase_order_id']]);
    }

    // 如果质检通过，更新库存
    if ($quality_check_result === 'passed') {
        // 检查库存是否已存在
        $stmt = $pdo->prepare("
            SELECT id, quantity_on_hand 
            FROM inventory 
            WHERE product_id = ? AND storage_location_id = ?
        ");
        $stmt->execute([$orderItem['product_id'], $storage_location_id]);
        $inventory = $stmt->fetch();

        if ($inventory) {
            // 更新现有库存
            $stmt = $pdo->prepare("
                UPDATE inventory 
                SET quantity_on_hand = quantity_on_hand + ?, last_updated = CURRENT_TIMESTAMP 
                WHERE id = ?
            ");
            $stmt->execute([$received_quantity, $inventory['id']]);
        } else {
            // 创建新库存记录
            $stmt = $pdo->prepare("
                INSERT INTO inventory (
                    product_id, 
                    storage_location_id, 
                    quantity_on_hand,
                    unit,
                    last_updated
                ) VALUES (?, ?, ?, (SELECT unit FROM products WHERE id = ?), CURRENT_TIMESTAMP)
            ");
            $stmt->execute([$orderItem['product_id'], $storage_location_id, $received_quantity, $orderItem['product_id']]);
        }
    }

    // 记录操作日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '原料入库',
        'material_receiving',
        $receiving_id,
        json_encode([
            'product_id' => $orderItem['product_id'],
            'product_name' => $orderItem['product_name'],
            'batch_number' => $batch_number,
            'received_quantity' => $received_quantity,
            'quality_check_result' => $quality_check_result
        ]),
        $_SERVER['REMOTE_ADDR']
    ]);

    $pdo->commit();
    $_SESSION['success'] = "入库记录已创建成功";
} catch (PDOException $e) {
    $pdo->rollBack();
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
} catch (Exception $e) {
    $pdo->rollBack();
    $_SESSION['error'] = $e->getMessage();
}

// 返回原页面
if (isset($_POST['order_id']) && $_POST['order_id']) {
    header("Location: material_receiving.php?order_id=" . $_POST['order_id']);
} else {
    header("Location: material_receiving.php");
}
exit;
