<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取订单ID
$order_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$order_id) {
    $_SESSION['error'] = "未指定订单ID";
    header("Location: purchase_orders.php");
    exit;
}

try {
    // 获取采购订单信息
    $stmt = $pdo->prepare("
        SELECT 
            po.id, 
            po.order_number, 
            po.order_date, 
            po.expected_delivery_date, 
            po.status, 
            po.total_amount,
            po.created_at,
            s.name AS supplier_name,
            s.contact_person AS supplier_contact,
            s.phone AS supplier_phone,
            u.username AS created_by
        FROM purchase_orders po
        JOIN suppliers s ON po.supplier_id = s.id
        LEFT JOIN users u ON po.created_by_user_id = u.id
        WHERE po.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        $_SESSION['error'] = "找不到该采购订单";
        header("Location: purchase_orders.php");
        exit;
    }

    // 获取订单项
    $stmt = $pdo->prepare("
        SELECT 
            poi.id,
            poi.quantity,
            poi.unit_price,
            poi.received_quantity,
            p.name AS product_name,
            p.specification,
            p.unit
        FROM purchase_order_items poi
        JOIN products p ON poi.product_id = p.id
        WHERE poi.purchase_order_id = ?
    ");
    $stmt->execute([$order_id]);
    $orderItems = $stmt->fetchAll();

    // 获取入库记录
    $stmt = $pdo->prepare("
        SELECT 
            mr.id,
            mr.received_date,
            mr.received_quantity,
            mr.batch_number,
            mr.quality_check_result,
            p.name AS product_name,
            p.unit,
            u.username AS inspector_name
        FROM material_receiving mr
        JOIN purchase_order_items poi ON mr.purchase_order_item_id = poi.id
        JOIN products p ON mr.product_id = p.id
        LEFT JOIN users u ON mr.inspector_id = u.id
        WHERE poi.purchase_order_id = ?
        ORDER BY mr.received_date DESC
    ");
    $stmt->execute([$order_id]);
    $receivingRecords = $stmt->fetchAll();
} catch (PDOException $e) {
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
    header("Location: purchase_orders.php");
    exit;
}

// 状态显示映射
$statusDisplay = [
    'pending' => ['text' => '待审批', 'class' => '待处理'],
    'approved' => ['text' => '已批准', 'class' => '进行中'],
    'ordered' => ['text' => '已下单', 'class' => '进行中'],
    'partially_received' => ['text' => '部分收货', 'class' => '进行中'],
    'received' => ['text' => '已收货', 'class' => '已完成'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];

$qualityResultDisplay = [
    'passed' => ['text' => '通过', 'class' => '已完成'],
    'failed' => ['text' => '不合格', 'class' => '待处理'],
    'pending' => ['text' => '待检验', 'class' => '进行中']
];

// 检查是否可以审核订单
$canApprove = $order['status'] === 'pending' && ($_SESSION['role_id'] == 1 || $_SESSION['role_id'] == 2); // 假设角色ID 1或2可以审核
$canEdit = $order['status'] === 'pending'; // 只有待审批状态可以编辑
$canCancel = in_array($order['status'], ['pending', 'approved']); // 待审批或已批准状态可以取消
$canReceive = in_array($order['status'], ['ordered', 'partially_received']); // 已下单或部分收货状态可以入库
?>

<!DOCTYPE html>
<html>

<head>
    <title>采购订单详情</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .order-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .order-info {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 30px;
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 15px;
        }

        .info-group {
            display: flex;
            flex-direction: column;
        }

        .info-label {
            font-weight: bold;
            color: #555;
            margin-bottom: 5px;
        }

        .info-value {
            color: #333;
        }

        .action-buttons {
            display: flex;
            gap: 10px;
            justify-content: flex-end;
            margin-bottom: 20px;
        }

        .section-title {
            border-bottom: 2px solid #3498db;
            padding-bottom: 8px;
            margin-bottom: 20px;
            color: #2c3e50;
        }

        .total-row {
            font-weight: bold;
            background-color: #f0f0f0;
        }

        .receipt-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .receipt-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="order-header">
            <h2>采购订单详情</h2>
            <div>
                <a href="purchase_orders.php" class="btn" style="background-color: #6c757d;">返回列表</a>
            </div>
        </div>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <!-- 订单信息 -->
        <div class="order-info">
            <div class="info-group">
                <div class="info-label">订单编号</div>
                <div class="info-value"><?= htmlspecialchars($order['order_number']) ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">状态</div>
                <div class="info-value">
                    <span class="status-tag <?= $statusDisplay[$order['status']]['class'] ?>">
                        <?= $statusDisplay[$order['status']]['text'] ?>
                    </span>
                </div>
            </div>
            <div class="info-group">
                <div class="info-label">供应商</div>
                <div class="info-value"><?= htmlspecialchars($order['supplier_name']) ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">联系人</div>
                <div class="info-value"><?= htmlspecialchars($order['supplier_contact'] ?? '未指定') ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">联系电话</div>
                <div class="info-value"><?= htmlspecialchars($order['supplier_phone'] ?? '未指定') ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">订单日期</div>
                <div class="info-value"><?= date('Y-m-d', strtotime($order['order_date'])) ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">预计交货日期</div>
                <div class="info-value"><?= date('Y-m-d', strtotime($order['expected_delivery_date'])) ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">创建人</div>
                <div class="info-value"><?= htmlspecialchars($order['created_by'] ?? '未知') ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">创建时间</div>
                <div class="info-value"><?= date('Y-m-d H:i', strtotime($order['created_at'])) ?></div>
            </div>
            <div class="info-group">
                <div class="info-label">订单总金额</div>
                <div class="info-value">¥<?= number_format($order['total_amount'], 2) ?></div>
            </div>
        </div>

        <!-- 操作按钮 -->
        <div class="action-buttons">
            <?php if ($canEdit): ?>
                <a href="purchase_order_edit.php?id=<?= $order['id'] ?>" class="btn-edit">编辑订单</a>
            <?php endif; ?>

            <?php if ($canApprove): ?>
                <a href="purchase_order_approve.php?id=<?= $order['id'] ?>" class="btn-approve">审核订单</a>
            <?php endif; ?>

            <?php if ($canCancel): ?>
                <a href="purchase_order_cancel.php?id=<?= $order['id'] ?>" class="btn-cancel" onclick="return confirm('确定要取消这个订单吗？')">取消订单</a>
            <?php endif; ?>

            <?php if ($canReceive): ?>
                <a href="material_receiving.php?order_id=<?= $order['id'] ?>" class="btn">登记入库</a>
            <?php endif; ?>
        </div>

        <!-- 订单项目 -->
        <h3 class="section-title">订单明细</h3>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>产品</th>
                        <th>规格</th>
                        <th>单位</th>
                        <th>数量</th>
                        <th>单价</th>
                        <th>金额</th>
                        <th>已收货</th>
                        <th>剩余</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orderItems as $item): ?>
                        <?php
                        $amount = $item['quantity'] * $item['unit_price'];
                        $remaining = $item['quantity'] - $item['received_quantity'];
                        ?>
                        <tr>
                            <td><?= htmlspecialchars($item['product_name']) ?></td>
                            <td><?= htmlspecialchars($item['specification'] ?? '无规格') ?></td>
                            <td><?= htmlspecialchars($item['unit']) ?></td>
                            <td><?= number_format($item['quantity'], 2) ?></td>
                            <td>¥<?= number_format($item['unit_price'], 2) ?></td>
                            <td>¥<?= number_format($amount, 2) ?></td>
                            <td><?= number_format($item['received_quantity'], 2) ?></td>
                            <td><?= number_format($remaining, 2) ?></td>
                        </tr>
                    <?php endforeach; ?>
                    <tr class="total-row">
                        <td colspan="5" style="text-align: right;">总计：</td>
                        <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                        <td colspan="2"></td>
                    </tr>
                </tbody>
            </table>
        </div>

        <!-- 入库记录 -->
        <?php if (!empty($receivingRecords)): ?>
            <h3 class="section-title">入库记录</h3>

            <?php foreach ($receivingRecords as $record): ?>
                <?php
                $qualityInfo = $qualityResultDisplay[$record['quality_check_result']] ?? ['text' => $record['quality_check_result'], 'class' => ''];
                ?>
                <div class="receipt-card">
                    <div class="receipt-header">
                        <div>
                            <strong>批次: <?= htmlspecialchars($record['batch_number']) ?></strong>
                            <span class="status-tag <?= $qualityInfo['class'] ?>"><?= $qualityInfo['text'] ?></span>
                        </div>
                        <div>
                            <?= date('Y-m-d H:i', strtotime($record['received_date'])) ?>
                        </div>
                    </div>
                    <div>
                        <span class="info-label">物料：</span>
                        <?= htmlspecialchars($record['product_name']) ?>
                    </div>
                    <div>
                        <span class="info-label">数量：</span>
                        <?= number_format($record['received_quantity'], 2) ?> <?= htmlspecialchars($record['unit']) ?>
                    </div>
                    <div>
                        <span class="info-label">质检员：</span>
                        <?= htmlspecialchars($record['inspector_name'] ?? '未指定') ?>
                    </div>
                    <div style="margin-top: 10px; text-align: right;">
                        <a href="material_receiving_detail.php?id=<?= $record['id'] ?>" class="btn-link">查看详情</a>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
</body>

</html>