<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 系统模块列表
$modules = [
    '供应链与原料管理',
    '生产加工管理',
    '质量控制与食品安全',
    '库存管理',
    '订单与销售管理',
    '财务管理',
    '物流与配送管理',
    '客户与市场管理',
    '报表与数据分析',
    '系统设置'
];

// 获取所有角色
$roles = $pdo->query("SELECT id, name, description FROM roles ORDER BY id")->fetchAll();

// 更新权限配置
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 验证CSRF Token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: role_permissions.php");
        exit;
    }

    $role_id = (int)$_POST['role_id'];
    $permissions = $_POST['permissions'] ?? [];

    try {
        // 检查角色是否存在
        $stmt = $pdo->prepare("SELECT count(*) FROM roles WHERE id = ?");
        $stmt->execute([$role_id]);
        if ($stmt->fetchColumn() == 0) {
            throw new Exception("选择的角色不存在");
        }

        $pdo->beginTransaction();

        // 获取角色名称（用于日志记录）
        $stmt = $pdo->prepare("SELECT name FROM roles WHERE id = ?");
        $stmt->execute([$role_id]);
        $role_name = $stmt->fetchColumn();

        // 记录操作
        $permissionData = [];
        foreach ($modules as $module) {
            $permissionData[$module] = $permissions[$module] ?? '无';
        }

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");

        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '更新角色权限',
            'role',
            $role_id,
            json_encode([
                'role_id' => $role_id,
                'role_name' => $role_name,
                'permissions' => $permissionData
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "角色 '$role_name' 的权限配置已更新";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    }
    header("Location: role_permissions.php");
    exit;
}

// 默认选择第一个角色
$selectedRoleId = $roles[0]['id'] ?? 0;
?>
<!DOCTYPE html>
<html>

<head>
    <title>角色权限管理 - 果易管系统</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>角色权限配置</h2>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="form-container">
            <form method="POST">
                <?= csrf_field() ?>
                <div class="form-group">
                    <label>选择角色：</label>
                    <select name="role_id" id="role-select" required>
                        <?php foreach ($roles as $role): ?>
                            <option value="<?= $role['id'] ?>">
                                <?= htmlspecialchars($role['name']) ?> - <?= htmlspecialchars($role['description']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="permission-grid">
                    <?php foreach ($modules as $module): ?>
                        <div class="permission-item">
                            <h4><?= htmlspecialchars($module) ?></h4>
                            <select name="permissions[<?= $module ?>]" required>
                                <option value="无">无权限</option>
                                <option value="只读">只读</option>
                                <option value="编辑">编辑</option>
                                <option value="管理">管理</option>
                            </select>
                        </div>
                    <?php endforeach; ?>
                </div>

                <div class="form-group">
                    <button type="submit" class="btn">保存配置</button>
                </div>
            </form>
        </div>

        <div class="info-block">
            <h3>权限说明</h3>
            <ul>
                <li><strong>无权限</strong>: 无法访问该模块</li>
                <li><strong>只读</strong>: 可查看但不能修改数据</li>
                <li><strong>编辑</strong>: 可添加和修改数据，但无法删除</li>
                <li><strong>管理</strong>: 完全控制权限，包括删除数据</li>
            </ul>
            <div class="alert alert-info">
                注意：管理员角色始终拥有所有模块的完全权限，无法修改。
            </div>
        </div>
    </div>

    <script>
        // 管理员角色ID
        const adminRoleId = 1; // 假设管理员角色ID为1

        // 监听角色选择变化
        document.getElementById('role-select').addEventListener('change', function() {
            const isAdmin = this.value == adminRoleId;

            // 如果选择的是管理员角色，禁用所有权限选择并设为"管理"
            const permissionSelects = document.querySelectorAll('.permission-item select');
            permissionSelects.forEach(select => {
                if (isAdmin) {
                    select.value = '管理';
                    select.disabled = true;
                } else {
                    select.disabled = false;
                }
            });
        });

        // 页面加载时触发一次，初始化状态
        document.addEventListener('DOMContentLoaded', function() {
            const event = new Event('change');
            document.getElementById('role-select').dispatchEvent(event);
        });
    </script>
</body>

</html>